@@ -3,7 +3,7 @@ from optparse import OptionParser
 import os, stat
 import sys
 import logging
-import gtk
+from gi.repository import Gtk
 
 import string
 from lxml import etree
@@ -11,6 +11,11 @@ from lxml import etree
 import httplib, httplib2
 import urllib2
 import mimetools, mimetypes
+from json import dumps, loads       #   for deserializing JSON data form javascript
+
+from pytrainer.extensions.mapviewer import MapViewer
+from pytrainer.extensions.osm import Osm
+from pytrainer.lib.localization import gtk_str
 
 class openstreetmap:
     def __init__(self, parent = None, pytrainer_main = None, conf_dir = None, options = None):
@@ -21,22 +26,21 @@ class openstreetmap:
         self.description = " "
         self.tags = ""
         self.visibility = "private"
+        self.mozTitle=""               # Keeps embedded mozilla document title while displaying map for private area selection
+        self.privBounds=[]             # Bounds of areas to be anonymized 
 
     def run(self, id, activity=None):  #TODO Convert to use activity...
         logging.debug(">>")
-        uri = "http://api.openstreetmap.org/api/0.6/gpx/create" #URI for uploading traces to OSM
-        if 'username' not in self.options or self.options['username'] == "" or 'password' not in self.options or self.options['password'] == "":
-            logging.error("Must have username and password configured")
-            msg = _("Must have username and password configured")
-            md = gtk.MessageDialog(self.pytrainer_main.windowmain.window1, gtk.DIALOG_DESTROY_WITH_PARENT, gtk.MESSAGE_ERROR, gtk.BUTTONS_CLOSE, msg)
-            md.set_title(_("Openstreetmap Extension Error"))
-            md.run()
-            md.destroy()
-            return
-        username = self.options['username']
-        password = self.options['password']
-        gpx_file = "%s/gpx/%s.gpx" % (self.conf_dir, id)
-        if os.path.isfile(gpx_file):
+        try:
+            uri = "http://api.openstreetmap.org/api/0.6/gpx/create" #URI for uploading traces to OSM
+            if 'username' not in self.options or self.options['username'] == "" or 'password' not in self.options or self.options['password'] == "":
+                logging.error("Must have username and password configured")
+                raise Exception("Must have username and password configured")
+            username = self.options['username']
+            password = self.options['password']
+            gpx_file = "%s/gpx/%s.gpx" % (self.conf_dir, id)
+            if not os.path.isfile(gpx_file):
+                raise Exception(str(gps_file) + ' File not found')
             #GPX file is ok and found, so open it
             logging.debug("GPX file: %s found, size: %d" % (gpx_file, os.path.getsize(gpx_file)))
             f = open(gpx_file, 'r')
@@ -52,12 +56,12 @@ class openstreetmap:
                 f = open(gpx_file, 'r')     #Reopen in readonly mode
             #Get extra info from user
             response=self.display_options_window()
-            if not response==gtk.RESPONSE_ACCEPT:
+            if not response==Gtk.ResponseType.ACCEPT:
                 f.close()
                 logging.debug("User abort")
                 return
             if self.makeanon:
-                logging.debug("User requested anonymising of GPX data")
+                logging.debug("User requested anonymizing of GPX data")
                 f.close()                   #Close standard gpxfile
                 gpx_file = self.make_gpx_private(gpx_file)
                 f = open(gpx_file, 'r')     #Open anonymous gpxfile in readonly mode
@@ -77,12 +81,12 @@ class openstreetmap:
             h.add_credentials(username, password)
             #Show user something is happening
             msg = _("Posting GPX trace to Openstreetmap\n\nPlease wait this could take several minutes")
-            md = gtk.MessageDialog(self.pytrainer_main.windowmain.window1, gtk.DIALOG_DESTROY_WITH_PARENT, gtk.MESSAGE_INFO, gtk.BUTTONS_NONE, msg)
+            md = Gtk.MessageDialog(self.pytrainer_main.windowmain.window1, Gtk.DialogFlags.DESTROY_WITH_PARENT, Gtk.MessageType.INFO, Gtk.ButtonsType.NONE, msg)
             md.set_title(_("Openstreetmap Extension Processing"))
             md.set_modal(True)
             md.show()
-            while gtk.events_pending(): # This allows the GUI to update
-                gtk.main_iteration()    # before completion of this entire action
+            while Gtk.events_pending(): # This allows the GUI to update
+                Gtk.main_iteration()    # before completion of this entire action
             logging.debug("before request posting")
             #POST request to OSM
             res, content = h.request(uri, 'POST', body=body, headers=headers)
@@ -95,39 +99,44 @@ class openstreetmap:
             #Close 'Please wait' dialog
             md.destroy()
             #Show the user the result
-            md = gtk.MessageDialog(self.pytrainer_main.windowmain.window1, gtk.DIALOG_DESTROY_WITH_PARENT, gtk.MESSAGE_INFO, gtk.BUTTONS_OK, res_msg)
+            md = Gtk.MessageDialog(self.pytrainer_main.windowmain.window1, Gtk.DialogFlags.DESTROY_WITH_PARENT, Gtk.MessageType.INFO, Gtk.ButtonsType.OK, res_msg)
             md.set_title(_("Openstreetmap Extension Upload Complete"))
             md.set_modal(False)
             md.run()
             md.destroy()
-
-        else:
-            logging.error("GPX file: %s NOT found!!!" % (gpx_file))
-        logging.debug("<<")
+        except Exception as e:
+                msg = _("Error while uploading file to OSM: " + str(e))
+                md = Gtk.MessageDialog(self.pytrainer_main.windowmain.window1, Gtk.DialogFlags.DESTROY_WITH_PARENT, Gtk.MessageType.ERROR, Gtk.ButtonsType.CLOSE, msg)
+                md.set_title(_("Openstreetmap Extension Error"))
+                md.run()
+                md.destroy()
+                return
+        finally:
+            logging.debug("<<")
 
     def display_options_window(self):
-        self.prefwindow = gtk.Dialog(title=_("Please add any additional information for this upload"), parent=None, flags=gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT, buttons=(gtk.STOCK_OK, gtk.RESPONSE_ACCEPT, gtk.STOCK_CANCEL, gtk.RESPONSE_REJECT))
+        self.prefwindow = Gtk.Dialog(title=_("Please add any additional information for this upload"), parent=None, flags=Gtk.DialogFlags.MODAL | Gtk.DialogFlags.DESTROY_WITH_PARENT, buttons=(Gtk.STOCK_OK, Gtk.ResponseType.ACCEPT, Gtk.STOCK_CANCEL, Gtk.ResponseType.REJECT))
         self.prefwindow.set_modal(False)
-        table = gtk.Table(1,2)
+        table = Gtk.Table(1,3)
         self.entryList = []
         #Add description
-        label = gtk.Label("<b>Description</b>")
+        label = Gtk.Label(label="<b>Description</b>")
         label.set_use_markup(True)
-        entry = gtk.Entry()
+        entry = Gtk.Entry()
         self.entryList.append(entry)
         table.attach(label,0,1,0,1)
         table.attach(entry,1,2,0,1)
         #Add tags
-        label = gtk.Label("<b>Tags</b>")
+        label = Gtk.Label(label="<b>Tags</b>")
         label.set_use_markup(True)
-        entry = gtk.Entry()
+        entry = Gtk.Entry()
         self.entryList.append(entry)
         table.attach(label,0,1,1,2)
         table.attach(entry,1,2,1,2)
         #Add visibility
-        label = gtk.Label("<b>Visibility</b>")
+        label = Gtk.Label(label="<b>Visibility</b>")
         label.set_use_markup(True)
-        combobox = gtk.combo_box_new_text()
+        combobox = Gtk.ComboBoxText()
         combobox.append_text("private")
         combobox.append_text("public")
         combobox.append_text("trackable")
@@ -137,14 +146,19 @@ class openstreetmap:
         self.entryList.append(combobox)
         table.attach(label,0,1,2,3)
         #Add anonymize GPX option
-        label = gtk.Label("<b>Anonymize GPX Data</b>")
+        label = Gtk.Label(label="<b>Anonymize GPX Data</b>")
         label.set_use_markup(True)
         table.attach(label,0,1,3,4)
-        checkbutton = gtk.CheckButton()
+        checkbutton = Gtk.CheckButton()
         table.attach(checkbutton,1,2,3,4)
         self.entryList.append(checkbutton)
-        #Buld dialog and show
-        self.prefwindow.vbox.pack_start(table)
+        #Add anon area selection button
+        button = Gtk.Button("Area selection")
+        button.connect("clicked",self.areaSelect)
+        table.attach(button,1,2,4,5)
+        self.entryList.append(button)
+        #Build dialog and show
+        self.prefwindow.vbox.pack_start(table, True, True, 0)
         self.prefwindow.show_all()
         self.prefwindow.connect("response", self.on_options_ok_clicked)
         response=self.prefwindow.run()
@@ -152,17 +166,89 @@ class openstreetmap:
         return response
 
     def on_options_ok_clicked(self, widget, response_id):
-        if not response_id == gtk.RESPONSE_ACCEPT:
+        if not response_id == Gtk.ResponseType.ACCEPT:
             return response_id
-        self.description = self.entryList[0].get_text()
+        self.description = gtk_str(self.entryList[0].get_text())
         if self.description == "":
             logging.debug("A description is required - setting to default")
             self.description = "Uploaded from pytrainer"
-        self.tags = self.entryList[1].get_text()
-        self.visibility = self.entryList[2].get_active_text()
+        self.tags = gtk_str(self.entryList[1].get_text())
+        self.visibility = gtk_str(self.entryList[2].get_active_text())
         self.makeanon = self.entryList[3].get_active()
         logging.debug("Description: %s, tags: %s, visibility: %s, makeanon: %s" % ( self.description, self.tags, self.visibility, self.makeanon) )
 
+    def areaSelect(self,dc):
+        """
+            Open a window with OSM map so user could select his private/anonymized area - 
+            all GPX dots in this area will be removed before uploading to OSM
+        """       
+        try:
+            wTree = Gtk.glade.XML(self.pytrainer_main.data_path+"extensions/openstreetmap/OSM_AnonSelection.glade")
+            self.privAreaWindow = wTree.get_widget("OSM_AnonSelection")
+            dic = {
+                "on_buttonOk_clicked" : self.privArea_Ok,
+                "on_buttonCancel_clicked" : self.privArea_Cancel
+            }
+            wTree.signal_autoconnect( dic )
+            mapviewer = MapViewer(self.pytrainer_main.data_path, pytrainer_main=self.pytrainer_main, box=wTree.get_widget("mapBox"))
+            json=None
+            if 'privPolygon' in self.options:
+                json=self.options['privPolygon']
+            htmlfile = Osm(data_path=self.pytrainer_main.data_path, waypoint=json, pytrainer_main=self.pytrainer_main).selectArea()
+            mapviewer.display_map(htmlfile=htmlfile)
+            mapviewer.moz.connect('title', self.parseTitle) 
+            self.privAreaWindow.show()
+
+        except Exception as e:
+                msg = "Could not init map selection screen, Error: " + str(e)
+                md = Gtk.MessageDialog(self.pytrainer_main.windowmain.window1, Gtk.DialogFlags.DESTROY_WITH_PARENT, Gtk.MessageType.ERROR, Gtk.ButtonsType.CLOSE, msg)
+                md.set_title(_("Error"))
+                md.run()
+                md.destroy()
+                return                
+
+    def parseTitle(self, moz):
+        "Event fired when document title was changed -> meaning polygon was changed"
+        if moz.get_title() != "":
+            self.mozTitle=str(moz.get_title())
+
+    def privArea_Cancel(self,button):
+        "Event fired when cancel button was pressed"
+        self.privAreaWindow.destroy()
+        
+    def privArea_Ok(self,button):
+        "Event fired when ok button was pressed"
+        logging.debug(">> privArea_Ok")
+        # save new private area polygon if changed
+        if self.mozTitle=="":
+            return
+        # try parsing JSON
+        try:
+            # verify json is correct by deserializing and serializing it
+            polygonString=dumps(loads(self.mozTitle))
+            # try saving
+            extensionDir = self.pytrainer_main.data_path + "/extensions" + "/openstreetmap"
+            if not os.path.isdir(extensionDir):
+                loggin.error(str(e))
+                raise Exception("Could not find extension path: " + str(extensionDir))
+            # save new options
+            self.options['privPolygon'] = polygonString
+            # convert dictionary to a lists set
+            savedOptions = []
+            for key in self.options:
+                savedOptions.append((key,self.options[key]))
+            # write new xml config file
+            self.parent.setExtensionConfParams(extensionDir, savedOptions)
+        except Exception as e:
+            logging.error(str(e))    
+            msg = _(str(e))
+            md = Gtk.MessageDialog(self.pytrainer_main.windowmain.window1, Gtk.DialogFlags.DESTROY_WITH_PARENT, Gtk.MessageType.ERROR, Gtk.ButtonsType.CLOSE, msg)
+            md.set_title(_("Error while saving extension configuration"))
+            md.run()
+            md.destroy()
+        finally:
+            self.privAreaWindow.destroy()
+                                
     def multipart_encode(self, fields, files, boundary = None, buffer = None):
         '''
             Multipart encode data for posting
@@ -176,7 +262,6 @@ class openstreetmap:
             buffer += '--%s\r\n' % boundary
             buffer += 'Content-Disposition: form-data; name="%s"' % key
             buffer += '\r\n\r\n' + value + '\r\n'
-        print files
         for (key, fd) in files:
             file_size = os.fstat(fd.fileno())[stat.ST_SIZE]
             filename = os.path.basename(fd.name)
@@ -202,15 +287,19 @@ class openstreetmap:
         filen = os.path.basename(gpx_file)
         tmpdir = self.pytrainer_main.profile.tmpdir
         anon_gpx_file = "%s/%s" % (tmpdir, filen)
-        
-        # Filtered home area, example Berlin
-        # corners NorthEast and SouthWest       
-        #TODO This needs to be a config item....
-        NE_LAT = 52.518
-        NE_LON = 13.408
-        SW_LAT = 52.4
-        SW_LON = 13.3
 
+        # get saved private area polygon
+        pP=loads(self.options['privPolygon'])
+        pP=pP['geometry']['coordinates'][0]
+        # converts polygon's 2D matrix into a vector of just the lats or lons
+        vector = lambda lonLat: [pP[i][lonLat] for i in range(len(pP))] # 0:lon, 1:lat
+        # try reading private area's bounds, stored as [lon,lat]
+        NE_LAT = max([pP[i][1] for i in range(len(pP))])
+        NE_LON = max([pP[i][0] for i in range(len(pP))])
+        SW_LAT = min([pP[i][1] for i in range(len(pP))])
+        SW_LON = min([pP[i][0] for i in range(len(pP))])
+        logging.info("Anonymizing Area: NE:%f,%f -> SW: %f,%f" % (NE_LON, NE_LAT, SW_LON, SW_LAT))
+            
         # Config parameters, not used yet
         FILTER_BOX = True
         ERASE_TIME  = True
