@@ -3,7 +3,7 @@
 import json
 import urllib
 import urllib2
-import gtk
+from gi.repository import Gtk
 import logging
 import webbrowser
 from subprocess import Popen, PIPE
@@ -69,7 +69,7 @@ class StravaUpload:
                 result = self.get_web_data(LOGIN_URL, values, "Validating user...")
                 token = result['token']
             else:
-                raise ConfigError, "Username or password missing"
+                raise ConfigError("Username or password missing")
             try:
                 with open(self.strava_token, 'w') as f:
                     f.write(token)
@@ -87,7 +87,7 @@ class StravaUpload:
                     if upload[0] == str(id):
                        upload_id = upload[1]
                        break
-        except IOError, e:
+        except IOError as e:
             logging.debug("Failed to read uploads file: %s" % e)
         return upload_id
 
@@ -95,7 +95,7 @@ class StravaUpload:
         try:
             with open(self.strava_uploads, 'a') as f:
                 f.write('%s,%s\n' % (id, upload_id))
-        except IOError, e:
+        except IOError as e:
             # log failure but continue...
             logging.debug("Failed to write upload id: %s" % e)
 
@@ -103,7 +103,7 @@ class StravaUpload:
         status = None
         values = { 'token': token }
         result = self.get_web_data(STATUS_URL % id, values, "Getting status...")
-        if result.has_key('activity_id'):
+        if 'activity_id' in result:
             status = result['activity_id']
         return status
 
@@ -150,14 +150,14 @@ class StravaUpload:
                     else:
                         # don't know status yet, assume it is processing
                         log = log + " Processing... check again soon!"
-        except (ValueError, KeyError), e:
+        except (ValueError, KeyError) as e:
             log = log + ("JSON error: %s." % e)
-        except ConfigError, e:
+        except ConfigError as e:
             log = log + ("config error: %s." % e)
-        except Exception, e:
+        except Exception as e:
             log = "Unknown exception: %s." % e
         logging.debug(log)
-        md = gtk.MessageDialog(self.pytrainer_main.windowmain.window1, gtk.DIALOG_DESTROY_WITH_PARENT, gtk.MESSAGE_INFO, gtk.BUTTONS_OK, log)
+        md = Gtk.MessageDialog(self.pytrainer_main.windowmain.window1, Gtk.DialogFlags.DESTROY_WITH_PARENT, Gtk.MessageType.INFO, Gtk.ButtonsType.OK, log)
         md.set_title(_("Strava Upload"))
         md.set_modal(False)
         md.run()
