@@ -21,7 +21,7 @@ import sys
 import shutil
 import logging
 
-import gtk
+from gi.repository import Gtk
 import httplib2
 
 import wordpresslib     #TODO remove need for this library
@@ -46,12 +46,12 @@ class wordpress:
     def run(self, id, activity=None):
         #Show user something is happening
         msg = _("Posting to Wordpress blog")
-        md = gtk.MessageDialog(self.pytrainer_main.windowmain.window1, gtk.DIALOG_DESTROY_WITH_PARENT, gtk.MESSAGE_INFO, gtk.BUTTONS_NONE, msg)
+        md = Gtk.MessageDialog(self.pytrainer_main.windowmain.window1, Gtk.DialogFlags.DESTROY_WITH_PARENT, Gtk.MessageType.INFO, Gtk.ButtonsType.NONE, msg)
         md.set_title(_("Wordpress Extension Processing"))
         md.set_modal(True)
         md.show()
-        while gtk.events_pending(): # This allows the GUI to update
-            gtk.main_iteration()    # before completion of this entire action
+        while Gtk.events_pending(): # This allows the GUI to update
+            Gtk.main_iteration()    # before completion of this entire action
         logging.debug("before request posting")
         options = self.options
         self.wordpressurl = options["wordpressurl"]
@@ -68,7 +68,6 @@ class wordpress:
             self.wp = wordpresslib.WordPressClient(self.wordpressurl, self.user, self.password) #TODO remove need for wordpresslib??
             self.error = False
         except Exception as e:
-            print e
             self.error = True
             self.log = "Url, user or pass are incorrect. Please, check your configuration"
         self.loadRecordInfo()
@@ -142,7 +141,7 @@ class wordpress:
         #Close 'Please wait' dialog
         md.destroy()
         #Show the user the result
-        md = gtk.MessageDialog(self.pytrainer_main.windowmain.window1, gtk.DIALOG_DESTROY_WITH_PARENT, gtk.MESSAGE_INFO, gtk.BUTTONS_OK, res_msg)
+        md = Gtk.MessageDialog(self.pytrainer_main.windowmain.window1, Gtk.DialogFlags.DESTROY_WITH_PARENT, Gtk.MessageType.INFO, Gtk.ButtonsType.OK, res_msg)
         md.set_title(_("Wordpress Extension Upload Complete"))
         md.set_modal(False)
         md.run()
@@ -160,7 +159,13 @@ class wordpress:
             #htmlpath = googlemaps.drawMap(self.gpxfile,self.googlekey,htmlpath)    #TODO fix to use main googlemaps and remove extensions copy
             htmlpath = self.googlemaps.drawMap(self.activity)
             #create the kml file
-            os.system("gpsbabel -t -i gpx -f %s -o kml,points=0,line_color=ff0000ff -F %s" %(self.gpxfile,kmlpath)) #TODO fix to remove gpsbabel
+            #TODO fix to remove gpsbabel
+            subprocess.call(["gpsbabel",
+                             "-t",
+                             "-i", "gpx",
+                             "-f", self.gpxfile,
+                             "-o", "kml,points=0,line_color=ff0000ff",
+                             "-F", kmlpath])
 
             #gfile = self.wp.newMediaObject(self.gpxfile)
             gfile = self.wp.newMediaObject(gpxpath)
