@@ -56,6 +56,7 @@ import os
 import xmlrpclib
 import datetime
 import time
+import logging
 
 class WordPressException(exceptions.Exception):
 	"""Custom exception for WordPress client operations
@@ -152,7 +153,7 @@ class WordPressClient:
 		catObj = WordPressCategory()
 		catObj.id 			= int(cat['categoryId'])
 		catObj.name 		= cat['categoryName'] 
-		if cat.has_key('isPrimary'):
+		if 'isPrimary' in cat:
 			catObj.isPrimary 	= cat['isPrimary']
 		return catObj
 		
@@ -177,7 +178,7 @@ class WordPressClient:
 													self.password, numPosts)
 			for post in posts:
 				yield self._filterPost(post)	
-		except xmlrpclib.Fault, fault:
+		except xmlrpclib.Fault as fault:
 			raise WordPressException(fault)
 			
 	def getPost(self, postId):
@@ -185,7 +186,7 @@ class WordPressClient:
 		"""
 		try:
 			return self._filterPost(self._server.metaWeblog.getPost(str(postId), self.user, self.password))
-		except xmlrpclib.Fault, fault:
+		except xmlrpclib.Fault as fault:
 			raise WordPressException(fault)
 		
 	def getUserInfo(self):
@@ -200,7 +201,7 @@ class WordPressClient:
 			userObj.nickname = userinfo['nickname']
 			userObj.email = userinfo['email']
 			return userObj
-		except xmlrpclib.Fault, fault:
+		except xmlrpclib.Fault as fault:
 			raise WordPressException(fault)
 			
 	def getUsersBlogs(self):
@@ -215,7 +216,7 @@ class WordPressClient:
 				blogObj.isAdmin = blog['isAdmin']
 				blogObj.url = blog['url']
 				yield blogObj
-		except xmlrpclib.Fault, fault:
+		except xmlrpclib.Fault as fault:
 			raise WordPressException(fault)
 			
 	def newPost(self, post, publish):
@@ -223,7 +224,7 @@ class WordPressClient:
 		"""
 		blogContent = {
 			'title' : post.title,
-			'description' : post.description	
+			'description' : "<![CDATA["+post.description+"]]>"	
 		}
 		
 		# add categories
@@ -237,6 +238,8 @@ class WordPressClient:
 	
 		# insert new post
 		idNewPost = int(self._server.metaWeblog.newPost(self.blogId, self.user, self.password, blogContent, 0))
+		logging.debug("idNewPost: %d" % idNewPost)
+		logging.debug(blogContent)
 		
 		# set categories for new post
 		self.setPostCategories(idNewPost, categories)
@@ -255,7 +258,7 @@ class WordPressClient:
 													self.password)
 			for cat in categories:
 				yield self._filterCategory(cat)	
-		except xmlrpclib.Fault, fault:
+		except xmlrpclib.Fault as fault:
 			raise WordPressException(fault)
 
 	def setPostCategories(self, postId, categories):
@@ -307,7 +310,7 @@ class WordPressClient:
 		try:
 			return self._server.blogger.deletePost('', postId, self.user, 
 											 self.password)
-		except xmlrpclib.Fault, fault:
+		except xmlrpclib.Fault as fault:
 			raise WordPressException(fault)
 
 	def getCategoryList(self):
@@ -322,7 +325,7 @@ class WordPressClient:
 					self.categories.append(self._filterCategory(cat))	
 
 			return self.categories
-		except xmlrpclib.Fault, fault:
+		except xmlrpclib.Fault as fault:
 			raise WordPressException(fault)		
 
 	def getCategoryIdFromName(self, name):
@@ -337,7 +340,7 @@ class WordPressClient:
 		"""
 		try:
 			return self._server.mt.getTrackbackPings(postId)
-		except xmlrpclib.Fault, fault:
+		except xmlrpclib.Fault as fault:
 			raise WordPressException(fault)
 			
 	def publishPost(self, postId):
@@ -345,7 +348,7 @@ class WordPressClient:
 		"""
 		try:
 			return (self._server.mt.publishPost(postId, self.user, self.password) == 1)
-		except xmlrpclib.Fault, fault:
+		except xmlrpclib.Fault as fault:
 			raise WordPressException(fault)
 
 	def getPingbacks(self, postUrl):
@@ -353,7 +356,7 @@ class WordPressClient:
 		"""
 		try:
 			return self._server.pingback.extensions.getPingbacks(postUrl)
-		except xmlrpclib.Fault, fault:
+		except xmlrpclib.Fault as fault:
 			raise WordPressException(fault)
 			
 	def newMediaObject(self, mediaFileName):
@@ -373,6 +376,6 @@ class WordPressClient:
 									self.user, self.password, mediaStruct)
 			return result['url']
 			
-		except xmlrpclib.Fault, fault:
+		except xmlrpclib.Fault as fault:
 			raise WordPressException(fault)
 	
