@@ -22,9 +22,11 @@ from __future__ import with_statement
 
 import logging
 import os
-import StringIO
+from io import BytesIO
 from lxml import etree
 from pytrainer.lib.date import getDateTime
+from pytrainer.core.activity import Activity
+from sqlalchemy.orm import exc
 
 class garmintools():
 	def __init__(self, parent = None, data_path = None):
@@ -54,7 +56,7 @@ class garmintools():
 			with open(filename, 'r') as f:
 				xmlString = f.read()
 			#add a root element to make correct xml
-			fileString = StringIO.StringIO("<root>"+xmlString+"</root>")
+			fileString = BytesIO(b"<root>" + xmlString + b"</root>")
 			#parse string as xml
 			xmldoc = etree.parse(fileString)
 			#Parse XML schema
@@ -87,9 +89,10 @@ class garmintools():
 		if time is None:
 			return False
 		time = time[0].strftime("%Y-%m-%dT%H:%M:%SZ")
-		if self.parent.parent.ddbb.select("records","*","date_time_utc=\"%s\"" % (time)):
+		try:
+			self.parent.parent.ddbb.session.query(Activity).filter(Activity.date_time_utc == time).one()
 			return True
-		else:
+		except exc.NoResultFound:
 			return False
 
 	def getDetails(self, tree, startTime):
@@ -127,7 +130,7 @@ class garmintools():
 		if pointElement is not None:
 			#Try to get time from point
 			time = pointElement.get("time")
-			print "#TODO first time is different from time used by gpsbabel and has locale embedded: " + time
+			print("#TODO first time is different from time used by gpsbabel and has locale embedded: " + time)
 			return time
 		return None
 
