@@ -25,6 +25,8 @@ import xml.etree.cElementTree
 
 from pytrainer.gui.dialogs import fileChooserDialog, guiFlush
 from pytrainer.lib.xmlUtils import XMLParser
+from pytrainer.core.activity import Activity
+from sqlalchemy.orm import exc
 
 class garmingpx():
 	""" Plugin to import from a GPX file or files
@@ -33,7 +35,8 @@ class garmingpx():
 	"""
 	def __init__(self, parent = None, validate=False):
 		self.parent = parent
-		self.tmpdir = self.parent.conf.getValue("tmpdir")
+		self.pytrainer_main = parent.pytrainer_main
+		self.tmpdir = self.pytrainer_main.profile.tmpdir
 		self.validate = validate
 		self.data_path = os.path.dirname(__file__)
 		self.sport = self.getConfValue("Force_sport_to")
@@ -41,7 +44,7 @@ class garmingpx():
 	def getConfValue(self, confVar):
 		info = XMLParser(self.data_path+"/conf.xml")
 		code = info.getValue("pytrainer-plugin","plugincode")
-		plugindir = self.parent.conf.getValue("plugindir")
+		plugindir = self.pytrainer_main.profile.plugindir
 		if not os.path.isfile(plugindir+"/"+code+"/conf.xml"):
 			value = None
 		else:
@@ -77,8 +80,8 @@ class garmingpx():
 			return True
 		else:
 			#To validate GPX as used for pytrainer must test against both Topograpfix and Cluetrust
-			topografixXSLfile = os.path.realpath(self.parent.parent.data_path)+ "/schemas/Topografix_gpx11.xsd"
-			cluetrustXSLfile = os.path.realpath(self.parent.parent.data_path)+ "/schemas/Cluetrust_gpxdata10.xsd"
+			topografixXSLfile = os.path.realpath(self.pytrainer_main.data_path)+ "/schemas/Topografix_gpx11.xsd"
+			cluetrustXSLfile = os.path.realpath(self.pytrainer_main.data_path)+ "/schemas/Cluetrust_gpxdata10.xsd"
 			from lib.xmlValidation import xmlValidator
 			validator = xmlValidator()
 			return validator.validateXSL(filename, topografixXSLfile) and validator.validateXSL(filename, cluetrustXSLfile)
@@ -89,9 +92,10 @@ class garmingpx():
 			only valid for GPX files with a single activity 
 		"""
 		time = self.detailsFromGPX(filename)
-		if self.parent.parent.ddbb.select("records","*","date_time_utc=\"%s\"" % (time)):
+		try:
+			self.pytrainer_main.ddbb.session.query(Activity).filter(Activity.date_time_utc == time).one()
 			return True
-		else:
+		except exc.NoResultFound:
 			return False
 
 	def getSport(self, filename):
@@ -110,5 +114,3 @@ class garmingpx():
 			return None
 		else:
 			return timeElement.text
-
-		
