@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: iso-8859-1 -*-
 
-#Copyright (C) 
+#Copyright (C)
 
 #Based on plugin by Fiz Vazquez vud1@sindominio.net
 
@@ -25,7 +25,8 @@ from lxml import etree
 
 from pytrainer.lib.xmlUtils import XMLParser
 from pytrainer.gui.dialogs import fileChooserDialog, guiFlush
-
+from pytrainer.core.activity import Activity
+from sqlalchemy.orm import exc
 
 class garminhrfile():
 	""" Plugin to import from a Garmin Training Center (version 1) file (as outputed from gpsbabel)
@@ -37,7 +38,8 @@ class garminhrfile():
 	"""
 	def __init__(self, parent = None, validate=False):
 		self.parent = parent
-		self.tmpdir = self.parent.conf.getValue("tmpdir")
+		self.pytrainer_main = parent.pytrainer_main
+		self.tmpdir = self.pytrainer_main.profile.tmpdir
 		self.data_path = os.path.dirname(__file__)
 		self.validate = validate
 		self.sport = self.getConfValue("Force_sport_to")
@@ -45,7 +47,7 @@ class garminhrfile():
 	def getConfValue(self, confVar):
 		info = XMLParser(self.data_path+"/conf.xml")
 		code = info.getValue("pytrainer-plugin","plugincode")
-		plugindir = self.parent.conf.getValue("plugindir")
+		plugindir = self.pytrainer_main.profile.plugindir
 		if not os.path.isfile(plugindir+"/"+code+"/conf.xml"):
 			value = None
 		else:
@@ -86,7 +88,7 @@ class garminhrfile():
 			logging.debug("Not validating %s" % (filename) )
 			return True
 		else: #Validate TCXv1, note are validating against gpsbabels 'broken' result...
-			xslfile = os.path.realpath(self.parent.parent.data_path)+ "/schemas/GarminTrainingCenterDatabase_v1-gpsbabel.xsd"
+			xslfile = os.path.realpath(self.pytrainer_main.data_path)+ "/schemas/GarminTrainingCenterDatabase_v1-gpsbabel.xsd"
 			from lib.xmlValidation import xmlValidator
 			validator = xmlValidator()
 			return validator.validateXSL(filename, xslfile)
@@ -101,12 +103,11 @@ class garminhrfile():
 			logging.debug("Error no time found in track")
 			return False
 		else:
-			time = timeElement.text	
-			#comparing date and start time (sport may have been changed in DB after import)
-			if self.parent.parent.ddbb.select("records","*","date_time_utc=\"%s\"" % (time)):
-				logging.debug("Not importing track for time %s" % (time))
+			time = timeElement.text
+			try:
+				self.pytrainer_main.ddbb.session.query(Activity).filter(Activity.date_time_utc == time).one()
 				return False
-			else:
+			except exc.NoResultFound:
 				return True
 
 	def getTracks(self, filename):
@@ -122,7 +123,7 @@ class garminhrfile():
 				tracks = sportLevel.findall(".//{http://www.garmin.com/xmlschemas/TrainingCenterDatabase/v1}Track")
 				result.append((sport, tracks))
 			except:
-				print "No entries for sport %s" % sport
+				print("No entries for sport %s" % sport)
 		return result
 
 	def createGPXfile(self, gpxfile, track):
@@ -131,5 +132,4 @@ class garminhrfile():
 		xslt_doc = etree.parse(self.data_path+"/translate.xsl")
 		transform = etree.XSLT(xslt_doc)
 		result_tree = transform(track)
-		result_tree.write(gpxfile, xml_declaration=True)
-
+		result_tree.write(gpxfile, xml_declaration=True, encoding='UTF-8')
