@@ -21,8 +21,10 @@ import os, sys
 import logging
 from lxml import etree
 from pytrainer.lib.xmlUtils import XMLParser
+from pytrainer.core.activity import Activity
+from sqlalchemy.orm import exc
 
-import commands
+import subprocess
 
 class garminhr():
 	""" Plugin to import from a Garmin device using gpsbabel
@@ -33,7 +35,8 @@ class garminhr():
 	"""
 	def __init__(self, parent = None, validate=False):
 		self.parent = parent
-		self.tmpdir = self.parent.conf.getValue("tmpdir")
+		self.pytrainer_main = parent.pytrainer_main
+		self.tmpdir = self.pytrainer_main.profile.tmpdir
 		self.data_path = os.path.dirname(__file__)
 		self.validate = validate
 		self.input_dev = self.getConfValue("device")
@@ -42,7 +45,7 @@ class garminhr():
 	def getConfValue(self, confVar):
 		info = XMLParser(self.data_path+"/conf.xml")
 		code = info.getValue("pytrainer-plugin","plugincode")
-		plugindir = self.parent.conf.getValue("plugindir")
+		plugindir = self.pytrainer_main.profile.plugindir
 		if not os.path.isfile(plugindir+"/"+code+"/conf.xml"):
 			value = None
 		else:
@@ -50,22 +53,36 @@ class garminhr():
 			value = info.getValue("pytrainer-plugin",confVar)
 		return value
 
+	def error_dialog(self, msg):
+		#TODO Remove Zenity below
+		subprocess.call(["zenity", "--error",
+		                 "--text='%s'" % msg])
+
 	def run(self):
 		logging.debug(">>")
 		importfiles = []
-		if not self.checkGPSBabelVersion("1.3.5"):
-			#TODO Remove Zenity below
-			os.popen("zenity --error --text='Must be using version 1.3.5 of GPSBabel for this plugin'");
-		elif self.garminDeviceExists():
+		no_device_msg = ("Can not handle Garmin device\n"
+		                 "Check your configuration\n"
+		                 "Current USB port is set "
+		                 "to:\t %s" % self.input_dev)
+
+		if self.garminDeviceExists():
 			try:
 				gpsbabelOutputFile = "%s/file.gtrnctr" % (self.tmpdir)
 				#TODO Remove Zenity below
-				outgps = commands.getstatusoutput("gpsbabel -t -i garmin -f %s -o gtrnctr -F %s | zenity --progress --pulsate --text='Loading Data' auto-close" % (self.input_dev, gpsbabelOutputFile) )
-				if outgps[0]==0:
-					if outgps[1] == "Found no Garmin USB devices.": # check localizations 
-						logging.error ("GPSBabel found no Garmin USB devices")
-						os.popen("zenity --error --text='GPSBabel found no Garmin USB devices'");
-						pass 
+				outgps = subprocess.Popen(
+				        "gpsbabel -t -i garmin -f %s -o gtrnctr -F %s "
+				        "| zenity --progress --pulsate --text='Loading Data' "
+				        "    auto-close" % (self.input_dev, gpsbabelOutputFile),
+				        stdout=subprocess.PIPE,
+				        stderr=subprocess.PIPE,
+				        shell=True)
+				stdout, stderr = outgps.communicate()
+				if outgps.returncode == 0:
+					if stdout == "Found no Garmin USB devices.": # check localizations
+						error_msg = "GPSBabel found no Garmin USB devices"
+						logging.error(error_msg)
+						self.error_dialog(error_msg)
 					else: #gpsbabel worked - now process file...
 						if self.valid_input_file(gpsbabelOutputFile):
 							for (sport, tracks) in self.getTracks(gpsbabelOutputFile):
@@ -84,33 +101,22 @@ class garminhr():
 						else:
 							logging.info("File %s failed validation" % (gpsbabelOutputFile))
 			except Exception:
-				#TODO Remove Zenity below
-				os.popen("zenity --error --text='Can not handle Garmin device\nCheck your configuration\nCurrent usb port is set to:\t %s'" %self.input_dev);
-				print sys.exc_info()[0]
+				self.dialog_msg(no_device_msg)
+				print(sys.exc_info()[0])
 		else: #No garmin device found
-			#TODO Remove Zenity below
-			os.popen("zenity --error --text='Can not handle Garmin device\nCheck your configuration\nCurrent usb port is set to:\t %s'" %self.input_dev);
+			self.error_dialog(no_device_msg)
 		logging.debug("<<")
 		return importfiles
 
-	def checkGPSBabelVersion(self, validVersion):
-		result = commands.getstatusoutput('gpsbabel -V')
-		if result[0] == 0:
-			version = result[1].split()
-			try:
-				if version[2] == validVersion:
-					return True
-				else:
-					logging.error("GPSBabel at version %s instead of expected version %s" % (version[2], validVersion))
-			except:
-				logging.error("Unexpected result from gpsbabel -V")
-				return False
-		return False
-
 	def garminDeviceExists(self):
 		try:
-			outmod = commands.getstatusoutput('/sbin/lsmod | grep garmin_gps')
-			if outmod[0]==256:	#there is no garmin_gps module loaded
+			process = subprocess.Popen('lsmod | grep garmin_gps',
+			                           stdout=subprocess.PIPE,
+			                           stderr=subprocess.PIPE,
+			                           shell=True)
+			stdout, stderr = process.communicate()
+			# stdout is empty if no garmin_gps module is loaded
+			if stdout != '':
 				self.input_dev = "usb:"
 				return True
 			else:
@@ -124,7 +130,7 @@ class garminhr():
 			logging.debug("Not validating %s" % (filename) )
 			return True
 		else: #Validate TCXv1, note are validating against gpsbabels 'broken' result...
-			xslfile = os.path.realpath(self.parent.parent.data_path)+ "/schemas/GarminTrainingCenterDatabase_v1-gpsbabel.xsd"
+			xslfile = os.path.realpath(self.pytrainer_main.data_path)+ "/schemas/GarminTrainingCenterDatabase_v1-gpsbabel.xsd"
 			from lib.xmlValidation import xmlValidator
 			validator = xmlValidator()
 			return validator.validateXSL(filename, xslfile)
@@ -142,7 +148,7 @@ class garminhr():
 				tracks = sportLevel.findall(".//{http://www.garmin.com/xmlschemas/TrainingCenterDatabase/v1}Track")
 				result.append((sport, tracks))
 			except:
-				print "No entries for sport %s" % sport
+				print("No entries for sport %s" % sport)
 		return result
 
 	def shouldImport(self, track):
@@ -155,12 +161,11 @@ class garminhr():
 			logging.debug("Error no time found in track")
 			return False
 		else:
-			time = timeElement.text	
-			#comparing date and start time (sport may have been changed in DB after import)
-			if self.parent.parent.ddbb.select("records","*","date_time_utc=\"%s\"" % (time)):
-				logging.debug("Not importing track for time %s" % (time))
+			time = timeElement.text
+			try:
+				self.pytrainer_main.ddbb.session.query(Activity).filter(Activity.date_time_utc == time).one()
 				return False
-			else:
+			except exc.NoResultFound:
 				return True
 
 	def createGPXfile(self, gpxfile, track):
@@ -169,7 +174,7 @@ class garminhr():
 		xslt_doc = etree.parse(self.data_path+"/translate.xsl")
 		transform = etree.XSLT(xslt_doc)
 		result_tree = transform(track)
-		result_tree.write(gpxfile, xml_declaration=True)
+		result_tree.write(gpxfile, xml_declaration=True, encoding='UTF-8')
 
 
 
