@@ -22,16 +22,19 @@ from __future__ import with_statement
 
 import logging
 import os
-import StringIO
+from io import BytesIO
 from lxml import etree
 
 from pytrainer.lib.xmlUtils import XMLParser
 from pytrainer.gui.dialogs import fileChooserDialog, guiFlush
+from pytrainer.core.activity import Activity
+from sqlalchemy.orm import exc
 
 class garmintools():
 	def __init__(self, parent = None, validate=False):
 		self.parent = parent
-		self.tmpdir = self.parent.conf.getValue("tmpdir")
+		self.pytrainer_main = parent.pytrainer_main
+		self.tmpdir = self.pytrainer_main.profile.tmpdir
 		self.data_path = os.path.dirname(__file__)
 		self.validate = validate
 		self.sport = self.getConfValue("Force_sport_to")
@@ -39,7 +42,7 @@ class garmintools():
 	def getConfValue(self, confVar):
 		info = XMLParser(self.data_path+"/conf.xml")
 		code = info.getValue("pytrainer-plugin","plugincode")
-		plugindir = self.parent.conf.getValue("plugindir")
+		plugindir = self.pytrainer_main.profile.plugindir
 		if not os.path.isfile(plugindir+"/"+code+"/conf.xml"):
 			value = None
 		else:
@@ -61,14 +64,14 @@ class garmintools():
 				#read file into string
 				with open(filename, 'r') as f:
 					xmlString = f.read()
-				fileString = StringIO.StringIO("<root>"+xmlString+"</root>")
+				fileString = BytesIO(b"<root>" + xmlString + b"</root>")
 				#parse string as xml
 				tree = etree.parse(fileString)
 				if not self.inDatabase(tree):
 					sport = self.getSport(tree)
-					gpxfile = "%s/garmintools-%d.gpx" % (self.tmpdir, len(importfiles))					
+					gpxfile = "%s/garmintools-%d.gpx" % (self.tmpdir, len(importfiles))
 					self.createGPXfile(gpxfile, tree)
-					importfiles.append((gpxfile, sport))					
+					importfiles.append((gpxfile, sport))
 				else:
 					logging.debug("%s already in database. Skipping import." % (filename,) )
 			else:
@@ -82,7 +85,7 @@ class garmintools():
 			logging.debug("Not validating %s" % (filename) )
 			return True
 		else:
-			print "Cannot validate garmintools dump files yet"
+			print("Cannot validate garmintools dump files yet")
 			logging.debug("Cannot validate garmintools dump files yet")
 			return True
 			'''xslfile = os.path.realpath(self.parent.parent.data_path)+ "/schemas/GarminTrainingCenterDatabase_v2.xsd"
@@ -93,9 +96,10 @@ class garmintools():
 	def inDatabase(self, tree):
 		#comparing date and start time (sport may have been changed in DB after import)
 		time = self.detailsFromFile(tree)
-		if self.parent.parent.ddbb.select("records","*","date_time_utc=\"%s\"" % (time)):
+		try:
+			self.pytrainer_main.ddbb.session.query(Activity).filter(Activity.date_time_utc == time).one()
 			return True
-		else:
+		except exc.NoResultFound:
 			return False
 
 	def getSport(self, tree):
@@ -118,7 +122,7 @@ class garmintools():
 		if pointElement is not None:
 			#Try to get time from point
 			time = pointElement.get("time")
-			print "#TODO first time is different from time used by gpsbabel and has locale embedded: " + time
+			print("#TODO first time is different from time used by gpsbabel and has locale embedded: " + time)
 			return time
 		return None
 
@@ -128,5 +132,5 @@ class garmintools():
 		xslt_doc = etree.parse(self.data_path+"/translate.xsl")
 		transform = etree.XSLT(xslt_doc)
 		result_tree = transform(tree)
-		result_tree.write(gpxfile, xml_declaration=True)
+		result_tree.write(gpxfile, xml_declaration=True, encoding='UTF-8')
 
