@@ -17,7 +17,8 @@
 #Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 import logging
-import os
+import warnings
+import os, os.path
 import dateutil.parser
 from dateutil.tz import tzlocal
 
@@ -26,6 +27,42 @@ from pytrainer.lib.gpx import Gpx
 from pytrainer.lib.graphdata import GraphData
 from pytrainer.environment import Environment
 from pytrainer.lib import uc
+from pytrainer.profile import Profile
+from pytrainer.lib.ddbb import DeclarativeBase, ForcedInteger, record_to_equipment
+from sqlalchemy import Column, Integer, Float, UnicodeText, Date, ForeignKey, String, Unicode, and_
+from sqlalchemy.orm import relationship, backref, reconstructor, deferred, joinedload
+from sqlalchemy.exc import InvalidRequestError
+
+class Lap(DeclarativeBase):
+    __tablename__ = 'laps'
+    avg_hr = Column(ForcedInteger)
+    calories = Column(ForcedInteger)
+    comments = Column(UnicodeText)
+    distance = Column(Float)
+    elapsed_time = Column(String(length=20))
+    end_lat = Column(Float)
+    end_lon = Column(Float)
+    id_lap = Column(Integer, primary_key=True)
+    intensity = Column(String(length=7))
+    lap_number = Column(ForcedInteger)
+    laptrigger = Column(String(length=9))
+    max_hr = Column(ForcedInteger)
+    max_speed = Column(Float)
+    record = Column(Integer, ForeignKey('records.id_record'), index=True, nullable=False)
+    start_lat = Column(Float)
+    start_lon = Column(Float)
+
+    @property
+    def duration(self):
+        return float(self.elapsed_time)
+
+class ActivityServiceException(Exception):
+
+    def __init__(self, value):
+        self.value = value
+
+    def __str__(self):
+        return repr(self.value)
 
 class ActivityService(object):
     '''
@@ -36,13 +73,13 @@ class ActivityService(object):
         logging.debug(">>")
         #It is an error to try to initialise with no reference to pytrainer_main
         if pytrainer_main is None:
-            print("Error - must initialise with a reference to the main pytrainer class")
+            logging.critical("Error - must initialise with a reference to the main pytrainer class")
             return
         self.pytrainer_main = pytrainer_main
         self.max_size = size
         self.pool = {}
         self.pool_queue = []
-        logging.debug("Initialising ActivityPool to size: %d" % size)
+        logging.debug("Initialising ActivityPool to size: %d", size)
         logging.debug("<<")
 
     def clear_pool(self):
@@ -52,33 +89,80 @@ class ActivityService(object):
         self.pool_queue = []
         logging.debug("<<")
 
-    def remove_activity(self, id):
+    def remove_activity_from_cache(self, id):
         sid = str(id)
-        if sid in self.pool.keys():
+        if sid in list(self.pool.keys()):
             logging.debug("Found activity in pool")
             self.pool_queue.remove(sid)
             del self.pool[sid]
 
     def get_activity(self, id):
+        if id is None:
+            warnings.warn("Deprecated call to get_activity with None id", DeprecationWarning, stacklevel=2)
+            return Activity()
         sid = str(id)
-        if sid in self.pool.keys():
+        if sid in list(self.pool.keys()):
             logging.debug("Found activity in pool")
             #Have accessed this activity, place at end of queue
             self.pool_queue.remove(sid)
             self.pool_queue.append(sid)
         else:
             logging.debug("Activity NOT found in pool")
-            self.pool[sid] = Activity(pytrainer_main=self.pytrainer_main, id=id)
+            self.pool[sid] = self.pytrainer_main.ddbb.session.query(Activity).options(
+                joinedload('sport'), joinedload('equipment'), joinedload('Laps')
+            ).filter(Activity.id == id).one()
             self.pool_queue.append(sid)
         if len(self.pool_queue) > self.max_size:
             sid_to_remove = self.pool_queue.pop(0)
-            logging.debug("Removing activity: %s" % sid_to_remove)
+            logging.debug("Removing activity: %s", sid_to_remove)
             del self.pool[sid_to_remove]
-        logging.debug("ActivityPool queue length: %d" % len(self.pool_queue))
-        logging.debug("ActivityPool queue: %s" % str(self.pool_queue))
+        logging.debug("ActivityPool queue length: %d", len(self.pool_queue))
+        logging.debug("ActivityPool queue: %s", self.pool_queue)
         return self.pool[sid]
 
-class Activity:
+    def remove_activity_from_db(self, activity):
+        """Delete a stored Activity."""
+
+        if not activity.id:
+            raise ActivityServiceException("Cannot remove activity which has not been stored: '{0}'.".format(activity.name))
+        try:
+            self.remove_activity_from_cache(activity.id)
+            self.pytrainer_main.ddbb.session.delete(activity)
+            self.pytrainer_main.ddbb.session.commit()
+            if activity.gpx_file and os.path.isfile(activity.gpx_file):
+                os.remove(activity.gpx_file)
+        except InvalidRequestError:
+             raise ActivityServiceException("Activity id %s not found" % activity.id)
+        logging.debug("Deleted activity: %s", activity.title)
+
+    def get_activities_for_day(self, date, sport=None):
+        """Iterates the activities for a specific date, optionally restricted by Sport)"""
+        if not sport:
+            activities = self.pytrainer_main.ddbb.session.query(Activity).filter(Activity.date == date).options(joinedload('Laps'))
+        else:
+            activities = self.pytrainer_main.ddbb.session.query(Activity).filter(and_(Activity.date == date, Activity.sport == sport)).options(joinedload('Laps'))
+        for activity in activities:
+            sid = str(activity.id)
+            if sid in self.pool:
+                yield self.pool[sid]
+            else:
+                self.pool[sid] = activity
+                self.pool_queue.append(sid)
+                yield activity
+
+    def get_activities_period(self, date_range, sport=None):
+        """Iterate over activities for a specific time period, optionally restricted by Sport.
+Does not add them to the cache."""
+        if not sport:
+            return self.pytrainer_main.ddbb.session.query(Activity).filter(Activity.date.between(date_range.start_date, date_range.end_date))
+        else:
+            return self.pytrainer_main.ddbb.session.query(Activity).filter(and_(Activity.date.between(date_range.start_date, date_range.end_date), Activity.sport == sport))
+
+    def get_all_activities(self):
+        """Iterates over all activities ordered by date"""
+        return self.pytrainer_main.ddbb.session.query(Activity).order_by('date')
+
+class Activity(DeclarativeBase):
     '''
     Class that knows everything about a particular activity
 
@@ -127,21 +211,48 @@ class Activity:
     lap_time                - (graphdata)
     pace_limit              - (int) maximum pace that is valid for this activity
     '''
-    def __init__(self, pytrainer_main=None, id=None):
+    __tablename__ = 'records'
+    average = Column(Float)
+    beats = Column(Float)
+    calories = Column(ForcedInteger)
+    comments = Column(UnicodeText)
+    date = Column(Date)
+    date_time_local = Column(String(length=40))
+    date_time_utc = Column(String(length=40))
+    distance = Column(Float)
+    duration = Column(ForcedInteger)
+    gpslog = deferred(Column(String(length=200)))
+    id = Column("id_record", Integer, primary_key=True)
+    maxbeats = Column(Float)
+    maxpace = Column(Float)
+    maxspeed = Column(Float)
+    pace = Column(Float)
+    sport_id = Column("sport", Integer, ForeignKey('sports.id_sports'),
+                          index=True, nullable=False)
+    title = Column(Unicode(length=200))
+    unegative = Column(Float)
+    upositive = Column(Float)
+
+    #relation definitions
+    sport = relationship("Sport", backref=backref("activities", order_by=date,
+                                                  cascade='all, delete-orphan'))
+    equipment = relationship("Equipment", secondary=record_to_equipment,
+                             backref=backref("activities", order_by=date))
+    Laps = relationship('Lap', backref=backref('activity'),
+                        order_by='Lap.lap_number',
+                        cascade='all, delete-orphan')
+
+    def __init__(self, **kwargs):
+        self._initialize()
+        super(Activity, self).__init__(**kwargs)
+
+    @reconstructor
+    def _initialize(self):
         logging.debug(">>")
         self.environment = Environment()
         self.uc = uc.UC()
-        self.id = id
-        #It is an error to try to initialise with no id
-        if self.id is None:
-            return
-        #It is an error to try to initialise with no reference to pytrainer_main
-        if pytrainer_main is None:
-            print("Error - must initialise with a reference to the main pytrainer class")
-            return
-        self.pytrainer_main = pytrainer_main
-        self.laps = None
-        self.has_data = False
+        self.profile = Profile()
+        self.has_data = True
         self._distance_data = {}
         self._time_data = {}
         self._lap_time = None
@@ -149,7 +260,6 @@ class Activity:
         self.time_pause = 0
         self.pace_limit = None
         self._gpx = None
-        self._init_from_db()
         self.x_axis = "distance"
         self.x_limits = (None, None)
         self.y1_limits = (None, None)
@@ -213,7 +323,7 @@ class Activity:
 
     @property
     def time_tuple(self):
-        return second2time(self.time)
+        return second2time(self.duration)
 
     @property
     def date_time(self):
@@ -227,6 +337,16 @@ class Activity:
     def starttime(self):
         return self.date_time.strftime("%X")
 
+    @property
+    def laps(self):
+        warnings.warn("Deprecated property Activity.laps called", DeprecationWarning, stacklevel=2)
+        ret = []
+        for lap in self.Laps:
+            d = dict(lap.__dict__)
+            d.pop('_sa_instance_state', None)
+            ret.append(d)
+        return ret
+
     def __str__(self):
         return '''
 tracks (%s)
@@ -274,7 +394,7 @@ tracks (%s)
 ''' % ('self.tracks', self.tracklist, self.laps, self.uc.us,
                 self.distance_data, self.time_data,
                 self.gpx_file, self.gpx, self.sport_name,
-                self.sport_id, self.title, self.date, self.time, self.time_tuple, self.beats,
+                self.sport_id, self.title, self.date, self.duration, self.time_tuple, self.beats,
                 self.maxbeats, self.comments, self.calories, self.id, self.date_time_local,
                 self.date_time_utc, self.date_time, self.starttime, self.distance, self.average,
                 self.upositive, self.unegative, self.maxspeed, self.maxpace, self.pace, self.has_data,
@@ -295,71 +415,29 @@ tracks (%s)
             #Parse GPX file
             #print "Activity initing GPX.. ",
             self._gpx = Gpx(filename=self.gpx_file) #TODO change GPX code to do less....
-            logging.info("GPX Distance: %s | distance (trkpts): %s | duration: %s | duration (trkpts): %s" % (self.gpx.total_dist, self.gpx.total_dist_trkpts, self.gpx.total_time, self.gpx.total_time_trkpts))
+            logging.info("GPX Distance: %s | distance (trkpts): %s | duration: %s | duration (trkpts): %s",
+                         self.gpx.total_dist, self.gpx.total_dist_trkpts, self.gpx.total_time,
+                         self.gpx.total_time_trkpts)
             time_diff = self.gpx.total_time_trkpts - self.gpx.total_time
             acceptable_lapse = 4 # number of seconds that duration calculated using lap and trkpts data can differ
             if time_diff > acceptable_lapse:
                 self.time_pause = time_diff
-                logging.debug("Identified non active time: %s s" % self.time_pause)
+                logging.debug("Identified non active time: %s s", self.time_pause)
             return self._gpx
         else:
             logging.debug("No GPX file found")
             return None
         logging.debug("<<")
 
-    def _init_from_db(self):
-        '''
-        Get activity information from the DB
-        '''
-        logging.debug(">>")
-        #Get base information
-        cols = ("sports.name","id_sports", "date","distance","time","beats","comments","duration",
-                                        "average","calories","id_record","title","upositive","unegative",
-                                        "maxspeed","maxpace","pace","maxbeats","date_time_utc","date_time_local", "sports.max_pace")
-        # outer join on sport id to workaround bug where sport reference is null on records from GPX import
-        db_result = self.pytrainer_main.ddbb.select("records left outer join sports on records.sport=sports.id_sports",
-                                ", ".join(cols),
-                                "id_record=\"%s\" " %self.id)
-        if len(db_result) == 1:
-            row = db_result[0]
-            self.sport_name = row[cols.index('sports.name')]
-            if self.sport_name == None:
-                self.sport_name = ""
-            self.sport_id = row[cols.index('id_sports')]
-            self.pace_limit = row[cols.index('sports.max_pace')]
-            if self.pace_limit == 0 or self.pace_limit == "":
-                self.pace_limit = None
-            self.title = row[cols.index('title')]
-            if self.title is None:
-                self.title = ""
-            self.date = row[cols.index('date')]
-            self.time = self._int(row[cols.index('time')])
-            self.duration = self._int(row[cols.index('duration')])
-            self.beats = self._int(row[cols.index('beats')])
-            self.comments = row[cols.index('comments')]
-            if self.comments is None:
-                self.comments = ""
-            self.calories = self._int(row[cols.index('calories')])
-            self.maxbeats = self._int(row[cols.index('maxbeats')])
-            self.date_time_local = row[cols.index('date_time_local')]
-            self.date_time_utc = row[cols.index('date_time_utc')]
-            self.distance = self._float(row[cols.index('distance')])
-            if not self.distance and self.gpx:
-                self.distance = self.gpx.total_dist
-            self.average = self._float(row[cols.index('average')])
-            self.upositive = self._float(row[cols.index('upositive')])
-            self.unegative = self._float(row[cols.index('unegative')])
-            self.maxspeed = self._float(row[cols.index('maxspeed')])
-            self.maxpace = self._float(row[cols.index('maxpace')])
-            self.pace = self._float(row[cols.index('pace')])
-            self.has_data = True
-        else:
-            raise Exception("Error - multiple results from DB for id: %s" % self.id)
-        #Get lap information
-        self.laps = self.pytrainer_main.ddbb.select_dict("laps",
-                                ("id_lap", "record", "elapsed_time", "distance", "start_lat", "start_lon", "end_lat", "end_lon", "calories", "lap_number", "intensity", "avg_hr", "max_hr", "max_speed", "laptrigger", "comments"),
-                                "record=\"%s\"" % self.id)
-        logging.debug("<<")
+    @property
+    def time(self):
+        warnings.warn("Deprecated property Activity.time called", DeprecationWarning, stacklevel=2)
+        return self.duration
+
+    @property
+    def sport_name(self):
+        warnings.warn("Deprecated property Activity.sport_name called", DeprecationWarning, stacklevel=2)
+        return self.sport.name
 
     def _generate_per_lap_graphs(self):
         '''Build lap based graphs...'''
@@ -398,7 +476,7 @@ tracks (%s)
         self.time_data['speed_lap'].set_color('#336633', '#336633')
         self.time_data['speed_lap'].graphType = "bar"
         for lap in self.laps:
-            time = float(lap['elapsed_time'].decode('utf-8')) # time in sql is a unicode string
+            time = float(lap['elapsed_time']) # time in sql is a unicode string
             dist = lap['distance']/1000 #distance in km
             try:
                 pace = time/(60*dist) #min/km
@@ -409,9 +487,9 @@ tracks (%s)
             except:
                 avg_speed = 0.0
             if self.pace_limit is not None and pace > self.pace_limit:
-                logging.debug("Pace (%s) exceeds limit (%s). Setting to 0" % (str(pace), str(self.pace_limit)))
+                logging.debug("Pace (%s) exceeds limit (%s). Setting to 0", pace, self.pace_limit)
                 pace = 0.0
-            logging.debug("Time: %f, Dist: %f, Pace: %f, Speed: %f" % (time, dist, pace, avg_speed))
+            logging.debug("Time: %f, Dist: %f, Pace: %f, Speed: %f", time, dist, pace, avg_speed)
             self._lap_time.addBars(x=time, y=10)
             self._lap_distance.addBars(x=self.uc.distance(dist), y=10)
             self.distance_data['pace_lap'].addBars(x=self.uc.distance(dist), y=pacekm2miles(pace))
@@ -474,7 +552,7 @@ tracks (%s)
         self._time_data['hr'] = GraphData(title=title,xlabel=xlabel, ylabel=ylabel)
         self._time_data['hr'].set_color('#00ff00', '#00ff00')
         #Heartrate as %
-        maxhr = self.pytrainer_main.profile.getMaxHR()
+        maxhr = self.profile.getMaxHR()
         title = _("Heart Rate (% of max)")
         xlabel = "%s (%s)" % (_('Distance'), self.uc.unit_distance)
         ylabel = "%s (%s)" % (_('Heart Rate'), _('%'))
@@ -496,7 +574,7 @@ tracks (%s)
             try:
                 pace = 60/track['velocity']
                 if self.pace_limit is not None and pace > self.pace_limit:
-                    logging.debug("Pace (%s) exceeds limit (%s). Setting to 0" % (str(pace), str(self.pace_limit)))
+                    logging.debug("Pace (%s) exceeds limit (%s). Setting to 0", pace, self.pace_limit)
                     pace = 0  #TODO this should be None when we move to newgraph...
             except Exception as e:
                 #print type(e), e
@@ -531,18 +609,18 @@ tracks (%s)
             self._time_data['hr_p'].addPoints(x=track['time_elapsed'], y=hr_p)
             self._time_data['cadence'].addPoints(x=track['time_elapsed'], y=track['cadence'])
         #Remove data with no values
-        for item in self._distance_data.keys():
+        for item in list(self._distance_data.keys()):
             if len(self._distance_data[item]) == 0:
-                logging.debug( "No values for %s. Removing...." % item )
+                logging.debug("No values for %s. Removing....", item)
                 del self._distance_data[item]
-        for item in self._time_data.keys():
+        for item in list(self._time_data.keys()):
             if len(self._time_data[item]) == 0:
-                logging.debug( "No values for %s. Removing...." % item )
+                logging.debug("No values for %s. Removing....", item)
                 del self._time_data[item]
         logging.debug("<<")
         #Add Heartrate zones graphs
         if 'hr' in self._distance_data:
-            zones = self.pytrainer_main.profile.getZones()
+            zones = self.profile.getZones()
             title = _("Heart Rate zone")
             xlabel = "%s (%s)" % (_('Distance'), self.uc.unit_distance)
             ylabel = "%s (%s)" % (_('Heart Rate'), _('bpm'))
@@ -606,13 +684,13 @@ tracks (%s)
         elif param == 'calories':
             return self.calories
         elif param == 'time':
-            if not self.time:
+            if not self.duration:
                 return ""
-            _hour ,_min, _sec = second2time(self.time)
+            _hour ,_min, _sec = second2time(self.duration)
             if _hour == 0:
                 return "%02d:%02d" % (_min, _sec)
             else:
                 return "%0d:%02d:%02d" % (_hour, _min, _sec)
         else:
-            print "Unable to provide value for unknown parameter (%s) for activity" % param
+            logging.error("Unable to provide value for unknown parameter (%s) for activity", param)
             return None
