@@ -19,16 +19,15 @@
 import os, sys
 import logging
 
-from lib.xmlUtils import XMLParser
-from lib.system import checkConf
+from .lib.xmlUtils import XMLParser
 
-from gui.windowextensions import WindowExtensions
+from .gui.windowextensions import WindowExtensions
 
 class Extension:
 	def __init__(self, data_path = None, parent = None):
 		self.data_path=data_path
-		self.conf = checkConf()
 		self.parent = parent
+		self.pytrainer_main = parent
 	
 	def getActiveExtensions(self):
 		retorno = []
@@ -61,7 +60,7 @@ class Extension:
 		name = info.getValue("pytrainer-extension","name")
 		description = info.getValue("pytrainer-extension","description")
 		code = info.getValue("pytrainer-extension","extensioncode")
-		extensiondir = self.conf.getValue("extensiondir")
+		extensiondir = self.pytrainer_main.profile.extensiondir
 		helpfile = pathExtension+"/"+info.getValue("pytrainer-extension","helpfile")
 		type = info.getValue("pytrainer-extension","type")
 	
@@ -76,7 +75,7 @@ class Extension:
 	def getExtensionConfParams(self,pathExtension):
 		info = XMLParser(pathExtension+"/conf.xml")
 		code = info.getValue("pytrainer-extension","extensioncode")
-		extensiondir = self.conf.getValue("extensiondir")
+		extensiondir = self.pytrainer_main.profile.extensiondir
 		params = {}
 		if not os.path.isfile(extensiondir+"/"+code+"/conf.xml"):
 			prefs = info.getAllValues("conf-values")
@@ -95,7 +94,7 @@ class Extension:
 	def setExtensionConfParams(self,pathExtension,savedOptions):
 		info = XMLParser(pathExtension+"/conf.xml")
 		code = info.getValue("pytrainer-extension","extensioncode")
-		extensiondir = self.conf.getValue("extensiondir")+"/"+code
+		extensiondir = self.pytrainer_main.profile.extensiondir+"/"+code
 		if not os.path.isdir(extensiondir):
 			os.mkdir(extensiondir)
 		if not os.path.isfile(extensiondir+"/conf.xml"):
@@ -113,7 +112,7 @@ class Extension:
 	
 
 	def getCodeConfValue(self,code,value):
-		extensiondir = self.conf.getValue("extensiondir")
+		extensiondir = self.pytrainer_main.profile.extensiondir
 		info = XMLParser(extensiondir+"/"+code+"/conf.xml")
 		return info.getValue("pytrainer-extension",value)
 		
@@ -126,34 +125,12 @@ class Extension:
 		extension_classname = info.getValue("pytrainer-extension","extensioncode")
 		extension_type = info.getValue("pytrainer-extension","type")
 		options = self.getExtensionConfParams(pathExtension)
-		logging.debug("Extension Filename: " + extension_filename )
-		logging.debug("Extension Classname: " + extension_classname)
-		logging.debug("Extension Type: " + extension_type)
-		logging.debug("Extension options: " + str(options))
+		logging.debug("Extension Filename: %s", extension_filename )
+		logging.debug("Extension Classname: %s", extension_classname)
+		logging.debug("Extension Type: %s", extension_type)
+		logging.debug("Extension options: %s", options)
 		sys.path.insert(0, extension_dir)
 		module = __import__(extension_filename)
 		extensionMain = getattr(module, extension_classname)
 		logging.debug('<<')
-		return extensionMain(parent=self, pytrainer_main=self.parent, conf_dir=self.conf.getValue("confdir"), options=options) 
-	
-	#def runExtension(self,pathExtension,id):
-		#info = XMLParser(pathExtension+"/conf.xml")
-		#bin = info.getValue("pytrainer-extension","executable")
-		#extensiontype = info.getValue("pytrainer-extension","type")
-		#binnary = pathExtension+"/"+bin
-		#params = ""
-		#for opt in self.getExtensionConfParams(pathExtension):
-		#	if opt[0]!="status" and opt[1]!="":
-		#		params += "--%s %s " %(opt[0],opt[1])
-		#if extensiontype=="record":
-		#	params += "--gpxfile %s/gpx/%s.gpx " %(self.conf.getValue("confdir"),id)
-		#	params += "--idrecord %s " %id
-		#bin = info.getValue("pytrainer-extension","executable")
-		#print params
-		#alert = os.popen("%s %s" %(binnary,params)).read()
-		
-		#from gui.warning import Warning
-		#warning = Warning(self.data_path)
-        #        warning.set_text(alert)
-        #        warning.run()
-
+		return extensionMain(parent=self, pytrainer_main=self.parent, conf_dir=self.pytrainer_main.profile.confdir, options=options)
