@@ -17,9 +17,16 @@
 #Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 from pytrainer.lib.fileUtils import fileUtils
-import gtk
+
+import gi
+try:
+        gi.require_version('WebKit2', '4.0')
+except ValueError:
+        pass
+
+from gi.repository import Gtk
 import logging
-import webkit
+from gi.repository import WebKit2
 
 class MapViewer:
 	def __init__(self, data_path = None, pytrainer_main=None, box=None):
@@ -30,15 +37,15 @@ class MapViewer:
 			logging.debug("Display box (%s) is None" % ( str(box)))
 			return
 		self.box = box
-		self.wkview = webkit.WebView()
+		self.wkview = WebKit2.WebView()
 		self.pack_box()
 		logging.debug("<<")
 
 	def pack_box(self):
 		logging.debug(">>")
-		scrolled_window = gtk.ScrolledWindow()
+		scrolled_window = Gtk.ScrolledWindow()
 		scrolled_window.add(self.wkview)
-		self.box.pack_start(scrolled_window, True, True)
+		self.box.pack_start(scrolled_window, True, True, 0)
 		self.box.show_all()
 		logging.debug("<<")
 
