@@ -5,8 +5,9 @@
 
 import os
 import re
+import html
 import logging
-import urllib           # for downloading cached versions of openlayers.js and openstreetmaps.js
+import requests         # for downloading cached versions of openlayers.js and openstreetmaps.js
 import time             # Used for checking if local cached file is current
     
 from pytrainer.lib.gpx import Gpx
@@ -17,10 +18,10 @@ from pytrainer.lib.uc import UC
 
 class Osm:
     # Default URLS
-    URLS = {'OpenLayers.js' : "http://openlayers.org/api/OpenLayers.js",
-            'OpenStreetMap.js' : "http://www.openstreetmap.org/openlayers/OpenStreetMap.js"}
+    URLS = {'OpenLayers.js' : "https://openlayers.org/api/OpenLayers.js",
+            'OpenStreetMap.js' : "https://www.openstreetmap.org/openlayers/OpenStreetMap.js"}
     # URLS that will not be cached
-    staticURLS = {'OpenLayers' : 'http://openlayers.org/api/'}                 #openlayers default location
+    staticURLS = {'OpenLayers' : 'https://openlayers.org/api/'}                 #openlayers default location
 
     def __init__(self, data_path = None, waypoint = None, pytrainer_main=None):
         logging.debug(">>")
@@ -36,12 +37,11 @@ class Osm:
         """Copy the contents of a file from a given URL to pytrainer's tmpdir
         """    
         logging.debug(">>")
-        print "Downloading %s" % (url)
-        webFile = urllib.urlopen(url)
+        logging.info("Downloading %s", url)
+        webFile = requests.get(url, headers={'User-Agent': 'pytrainer'})
         # always store downloaded files in tmpdir/cache
         localFile = open(self.tmpdir + '/cache/' + localfile, 'w')
-        localFile.write(webFile.read())
-        webFile.close()
+        localFile.write(webFile.text)
         localFile.close()
         logging.debug("<<")
         
@@ -55,7 +55,7 @@ class Osm:
         try:
             cachedir = self.tmpdir + '/cache';
             if not os.path.isdir(cachedir):
-                print "Creating %s folder" % (cachedir)
+                logging.debug("Creating %s folder", cachedir)
                 os.mkdir(cachedir)
                 
             for localfile in self.URLS:
@@ -72,7 +72,7 @@ class Osm:
                 self.URLS[localfile]='file://' + cachedir + '/' + localfile;
                 logging.info("Using %s file " % (self.URLS[localfile]))
         except Exception as e:
-            loggin.error("(%s) Error while downloading %s to local cache, using default hosted file instaed." \
+            logging.error("(%s) Error while downloading %s to local cache, using default hosted file instead." \
                            % (str(e), self.URLS[localfile]))
         logging.debug("<<")
     
@@ -99,14 +99,14 @@ class Osm:
                 points,levels = Points.encodePoints(pointlist)
                 points = points.replace("\\","\\\\")
                 laps = activity.laps
-                timeHours = int(activity.time) / 3600
-                timeMin = (float(activity.time) / 3600.0 - timeHours) * 60
+                timeHours = activity.duration / 3600
+                timeMin = (float(activity.duration) / 3600.0 - timeHours) * 60
                 time = "%d%s %02d%s" % (timeHours, _("h"), timeMin, _("min"))
                 startinfo = "<div class='info_content'>%s: %s</div>" % (activity.sport_name, activity.title)
                 finishinfo = "<div class='info_content'>%s: %s<br>%s: %s%s</div>" % (_("Time"), \
                             time, _("Distance"), activity.distance, self.uc.unit_distance)
-                startinfo = startinfo.encode('ascii', 'xmlcharrefreplace') #Encode for html
-                finishinfo = finishinfo.encode('ascii', 'xmlcharrefreplace') #Encode for html
+                startinfo = html.escape(startinfo) #Encode for html
+                finishinfo = html.escape(finishinfo) #Encode for html
 
                 self.createHtml_osm(polyline, startinfo, finishinfo, laps, attrlist, linetype)
             else:
