@@ -17,12 +17,12 @@
 #Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 import matplotlib
-matplotlib.use('GTKAgg')
+matplotlib.use('GTK3Agg')
 from matplotlib.figure import Figure
-from matplotlib.backends.backend_gtkagg import FigureCanvasGTKAgg as FigureCanvasGTK
-from matplotlib.backends.backend_gtkagg import NavigationToolbar2GTKAgg as NavigationToolbar
+from matplotlib.backends.backend_gtk3agg import FigureCanvasGTK3Agg as FigureCanvasGTK
+from matplotlib.backends.backend_gtk3 import NavigationToolbar2GTK3 as NavigationToolbar
 import matplotlib.pyplot as plt
-import pylab 
+import pylab
 import logging
 
 class DrawArea:
@@ -38,7 +38,7 @@ class DrawArea:
         logging.debug('<<')
 
     def stadistics(self,type,xvalues,yvalues,xlabel,ylabel,title,color=None,zones=None):
-        logging.debug('>>') 
+        logging.debug('>>')
         if len(xvalues[0]) < 1:
             #self.drawDefault()
             return False
@@ -49,38 +49,39 @@ class DrawArea:
             self.drawBars(xvalues,yvalues,xlabel,ylabel,title,color)
         elif type == "plot":
             self.drawPlot(xvalues,yvalues,xlabel,ylabel,title,color,zones)
-        elif type == "pie":
-            self.drawPie(xvalues,yvalues,xlabel,ylabel,title,color,zones)
+        elif type == "pie" or type == "histogram":
+            self.drawZones(type,xvalues,yvalues,xlabel,ylabel,title,color,zones)
         logging.debug('<<')
 
     def drawBars(self,xvalues,yvalues,xlabel,ylabel,title,color):
-        logging.debug('>>') 
-        logging.debug("Type: bars | title: "+str(title)+" | col: "+str(color)+" | xlabel: "+str(xlabel)+" | ylabel: "+str(ylabel))
+        logging.debug('>>')
+        logging.debug("Type: bars | title: %s"" | col: %s | xlabel: %s | ylabel: %s",
+                      title, color, xlabel, ylabel)
         self.removeVboxChildren()
         #figure = Figure(figsize=(6,4), dpi=72)
         figure = plt.figure()
-        logging.debug("Figure: %s" % str(figure) )
+        logging.debug("Figure: %s", figure)
         numCols=len(xvalues[0])
         xmod = 0.4
         self.showGraph=False
         axis = figure.add_subplot(111)
-        logging.debug("Axis: %s" % str(axis) )
+        logging.debug("Axis: %s", axis)
 
         if len(xvalues) == 1: #One axis
             barWidth = 0.8
             barOffset = 0.1
-            logging.debug("One axis, barWidth %f, barOffset %f" % (barWidth, barOffset) )
+            logging.debug("One axis, barWidth %f, barOffset %f", barWidth, barOffset)
         elif len(xvalues) == 2: #Twin axes
             barWidth = 0.4
             barOffset = 0.1
-            logging.debug("Twin axes, barWidth %f, barOffset %f" % (barWidth, barOffset) )
+            logging.debug("Twin axes, barWidth %f, barOffset %f", barWidth, barOffset)
         else: #Error
             logging.debug("Error: invalid number of axes" )
             return
 
         axis.set_xlabel(xlabel[0])
         axis.set_ylabel(ylabel[0])
-        logging.debug("Labels set x: %s, y: %s" % (xlabel[0], ylabel[0]) )
+        logging.debug("Labels set x: %s, y: %s", xlabel[0], ylabel[0])
         xvals = [x+barOffset for x in range(0, numCols)]
         yvals = [0] * numCols
         for i in range(0, numCols):
@@ -92,21 +93,21 @@ class DrawArea:
             yvals[i] = yval
         if self.showGraph:
             logging.debug("Drawing bars")
-            axis.bar(xvals, yvals, barWidth, color=color[0], align='edge')      
+            axis.bar(xvals, yvals, barWidth, color=color[0], align='edge')
         else:   #Only zero results
             logging.debug("No results to draw")
             pass
 
         axis.grid(True)
         axis.set_title("%s" %(title[0]))
-        logging.debug("Setting title to: %s" % title[0])
+        logging.debug("Setting title to: %s", title[0])
         for tl in axis.get_yticklabels():
-            logging.debug("Setting ticklabel color %s" % color[0])
+            logging.debug("Setting ticklabel color %s", color[0])
             tl.set_color('%s' %color[0])
 
         if len(xvalues) == 2: #Display twin axis
             ax2 = axis.twinx()
-            logging.debug("Axis 2: Twin axis: %s " % str(ax2))
+            logging.debug("Axis 2: Twin axis: %s", ax2)
             xvals = [x+barOffset+barWidth for x in range(0, numCols)]
             for i in range(0, numCols):
                 yval = yvalues[1][i]
@@ -118,35 +119,35 @@ class DrawArea:
             if self.showGraph:
                 logging.debug("Axis 2: Drawing bars")
                 ax2.bar(xvals, yvals, barWidth, color=color[1], align='edge')
-                logging.debug("Axis 2: Label set y: %s" % (ylabel[1]) )
+                logging.debug("Axis 2: Label set y: %s", ylabel[1])
                 ax2.set_ylabel(ylabel[1])
             else:   #Only zero results
                 logging.debug("Axis 2: No results to draw")
                 pass
             for tl in ax2.get_yticklabels():
                 tl.set_color('%s' %color[1])
-                logging.debug("Axis 2: Setting ticklabel color %s" % color[1])
+                logging.debug("Axis 2: Setting ticklabel color %s", color[1])
             _title = "%s vs %s" %(title[0],title[1])
-            logging.debug("Axis 2: Setting title to: %s" % _title)
+            logging.debug("Axis 2: Setting title to: %s", _title)
             axis.set_title(_title)
-        
+
         logging.debug("Setting x ticks")
-        tickLocations = [x+0.5 for x in xrange(0, numCols)]
+        tickLocations = [x+0.5 for x in range(0, numCols)]
         axis.set_xticks(tickLocations)
         axis.set_xticklabels(xvalues[0])
         logging.debug("Setting x limits")
         axis.set_xlim(0, numCols)
-        
+
         canvas = FigureCanvasGTK(figure) # a gtk.DrawingArea
-        logging.debug("Got canvas: %s" % (str(canvas)))
+        logging.debug("Got canvas: %s", canvas)
         canvas.show()
         logging.debug("Adding canvas to vbox")
-        self.vbox.pack_start(canvas, True, True)
+        self.vbox.pack_start(canvas, True, True, 0)
         #toolbar = NavigationToolbar(canvas, self.window)
         #self.vbox.pack_start(toolbar, False, False)
 
         for child in self.vbox.get_children():
-            logging.debug('Child available: '+str(child))
+            logging.debug('Child available: %s', child)
 
         logging.debug('<<')
 
@@ -155,7 +156,7 @@ class DrawArea:
         if x >= len(colors):
             x = x % len(colors)
         return colors[x]
-    
+
     def fmtTableText(self, x, valuesAreTime):
         if x <= 0.0001:
             return ' '
@@ -177,10 +178,10 @@ class DrawArea:
             yvalues needs to be a list of dicts e.g. [0]{'Kayak': {'Tue': 10.08, 'Fri': 17.579999999999998, 'Thu': 15.66, 'Sat': 30.619999999999997}, {'Run': {'Mon': 9.65, 'Sun': 15.59}}
         '''
         #TODO tidy
-        logging.debug('>>') 
-        logging.debug("Title: %s", (title, ))
-        logging.debug("X values received: %s", str(xvalues))
-        logging.debug("Y values received: %s", str(yvalues))
+        logging.debug('>>')
+        logging.debug("Title: %s", title)
+        logging.debug("X values received: %s", xvalues)
+        logging.debug("Y values received: %s", yvalues)
         self.removeVboxChildren()
 
         #Check how many axes to draw
@@ -193,31 +194,31 @@ class DrawArea:
         else: #Error
             return
 
-        keys = yvalues[0].keys() # days of the week
+        keys = list(yvalues[0].keys()) # days of the week
         numRows = len(keys)
         numCols = len(xvalues[0])
         if numRows == 0:
             return
         width = .8
-        #figure = plt.figure(figsize=(6,4), dpi=72) 
+        #figure = plt.figure(figsize=(6,4), dpi=72)
         figure = plt.figure()
-        logging.debug("Figure: %s" % str(figure) )
+        logging.debug("Figure: %s", figure)
         axis = plt.subplot(111)
 
         ybottoms = [0] * numCols
         yheights = [0] * numCols
-        inds = xrange(0, numCols)
+        inds = range(0, numCols)
         xvals = [x+barOffset for x in range(0, numCols)]
         cellText = []
         self.showGraph=False
-        
+
         for k in colors:
-        	if colors[k]==None: colors[k]=''
+            if colors[k]==None: colors[k]=''
 
         #Display first axis
         xticks = []
         for key in keys:
-            logging.debug("Day of the week: %s", str(key))
+            logging.debug("Day of the week: %s", key)
             for ind in inds:
                 ybottoms[ind] += yheights[ind]
                 yheights[ind] = 0 #Zero heights
@@ -243,17 +244,17 @@ class DrawArea:
         if len(xvalues) == 1:
             plt.title(title[0])
             axis.legend(loc=0)
-            
+
         axis.set_xlim(0,numCols)
 
-        logging.debug("X values first axis: %s", str(xvals))
-        logging.debug("Y values first axis: %s", str(yheights))
+        logging.debug("X values first axis: %s", xvals)
+        logging.debug("Y values first axis: %s", yheights)
 
         #Display twin axis
-        if len(xvalues) == 2: 
+        if len(xvalues) == 2:
             self.showGraph=False
             ax2 = axis.twinx()
-            keys = yvalues[1].keys()
+            keys = list(yvalues[1].keys())
             ybottoms = [0] * numCols
             yheights = [self.NEARLY_ZERO] * numCols
             for key in keys:
@@ -277,7 +278,7 @@ class DrawArea:
                         row = keys.index(key)
                         col = index
                         cellText[row][col] += " | %s" % (self.fmtTableText(height, valuesAreTime[1]))
-                        #print "Would add %s to %s %s" % (self.fmtTableText(height, valuesAreTime[1]), index, keys.index(key))                      
+                        #print "Would add %s to %s %s" % (self.fmtTableText(height, valuesAreTime[1]), index, keys.index(key))
                 if self.showGraph:
                     xvals = [x+barOffset+barWidth for x in range(0, numCols)]
                     #print "ax2", xvals, yheights, ybottoms
@@ -299,35 +300,36 @@ class DrawArea:
         axis.grid(True)
         canvas = FigureCanvasGTK(figure) # a gtk.DrawingArea
         canvas.show()
-        self.vbox.pack_start(canvas, True, True)
+        self.vbox.pack_start(canvas, True, True, 0)
         #toolbar = NavigationToolbar(canvas, self.window)
         #self.vbox.pack_start(toolbar, False, False)
 
         for child in self.vbox.get_children():
-            logging.debug('Child available: '+str(child))
+            logging.debug('Child available: %s', child)
 
         logging.debug('<<')
 
     def drawPlot(self,xvalues,yvalues,xlabel,ylabel,title,color,zones=None,xzones=None, ylimits=None, y1_linewidth=None):
-        logging.debug('>>')  
-        logging.debug("Type: plot | title: "+str(title)+" | col: "+str(color)+" | xlabel: "+str(xlabel)+" | ylabel: "+str(ylabel))
-        logging.debug('xlabel: '+str(xlabel)+' | ylabel: '+str(ylabel)+' | title: '+str(title))
+        logging.debug('>>')
+        logging.debug("Type: plot | title: %s | col: %s | xlabel: %s | ylabel: %s",
+                      title, color, xlabel, ylabel)
+        logging.debug('xlabel: %s | ylabel: %s | title: %s', xlabel, ylabel, title)
         self.removeVboxChildren()
         figure = plt.Figure()
-        logging.debug("Figure: %s" % str(figure) )
+        logging.debug("Figure: %s", figure)
         #figure.clf()
         i = 0
         for value in xvalues:
             if i<1:
-                logging.debug("i: %d, value: (%s) %s %s" % (i, str(value), str(xvalues), str(yvalues)) )
+                logging.debug("i: %d, value: (%s) %s %s", i, value, xvalues, yvalues)
                 axis = figure.add_subplot(111)
-                logging.debug("Axis: %s" % str(axis) )
+                logging.debug("Axis: %s", axis)
                 line = axis.plot(xvalues[i],yvalues[i], color=color[i])
-                logging.debug("Axis plotted, Line: %s" % str(line) )
+                logging.debug("Axis plotted, Line: %s", line)
                 if y1_linewidth is not None:
                     line[0].set_linewidth(y1_linewidth)
                 linewidth = line[0].get_linewidth()
-                    
+
                 axis.grid(True)
                 logging.debug("Axis grid on" )
                 for tl in axis.get_yticklabels():
@@ -345,7 +347,7 @@ class DrawArea:
                 maxX = max(xvalues[i])
             if i>=1:
                 ax2 = axis.twinx()
-                logging.debug("Axis2: Axis: %s" % str(ax2) )
+                logging.debug("Axis2: Axis: %s", ax2)
                 ax2.plot(xvalues[i], yvalues[i], color=color[i])
                 logging.debug("Axis2: plotted" )
                 for tl in ax2.get_yticklabels():
@@ -366,7 +368,7 @@ class DrawArea:
 
         ylim_min, ylim_max = axis.get_ylim()
         if ylimits is not None:
-            logging.debug("Using ylimits: %s" % str(ylimits))
+            logging.debug("Using ylimits: %s", ylimits)
             if ylimits[0] is not None:
                 ylim_min = ylimits[0]
             if ylimits[1] is not None:
@@ -374,110 +376,84 @@ class DrawArea:
             axis.set_ylim(ylim_min, ylim_max)
 
         canvas = FigureCanvasGTK(figure) # a gtk.DrawingArea
-        logging.debug("Canvas: %s" % str(canvas))
+        logging.debug("Canvas: %s", canvas)
         canvas.show()
-        self.vbox.pack_start(canvas, True, True)
+        self.vbox.pack_start(canvas, True, True, 0)
         toolbar = NavigationToolbar(canvas, self.window)
-        self.vbox.pack_start(toolbar, False, False)
-        
+        self.vbox.pack_start(toolbar, False, False, 0)
+
         for child in self.vbox.get_children():
-            logging.debug('Child available: '+str(child))
-        
+            logging.debug('Child available: %s', child)
+
         logging.debug('<<')
         return {'y1_min': ylim_min, 'y1_max': ylim_max, 'y1_linewidth': linewidth}
-    
-    def drawPie(self,xvalues,yvalues,xlabel,ylabel,title,color,zones=None):
+
+    def drawZones(self,shape,xvalues,yvalues,xlabel,ylabel,title,color,zones=None):
         logging.debug('>>')
-        logging.debug("Type: pie | title: "+str(title)+" | col: "+str(color)+" | xlabel: "+str(xlabel)+" | ylabel: "+str(ylabel))
+        logging.debug("Type: pie | title: %s | col: %s | xlabel: %s | ylabel: %s",
+                      title, color, xlabel, ylabel)
         self.removeVboxChildren()
-        #figure = Figure(figsize=(6,4), dpi=72)
         figure = Figure()
-        logging.debug("Figure: %s" % str(figure) )
+        logging.debug("Figure: %s", figure)
         axis = figure.add_subplot(111)
 
-        labels = []
-        colors = []
-        frac0 = 0
-        frac1 = 0
-        frac2 = 0
-        frac3 = 0
-        frac4 = 0
-        frac5 = 0
-        for zone in zones:
-            labels.insert(0,zone[3])
-            colors.insert(0,zone[2])
-    
-        labels.insert(0,_("rest"))
-        colors.insert(0,"#ffffff")
-    
-        for value in yvalues[0]:
-            if value <= zones[4][0]:
-                frac0+=1
-            elif value > zones[4][0] and value <= zones[4][1]:
-                frac1+=1
-            elif value > zones[3][0] and value <= zones[3][1]:
-                frac2+=1
-            elif value > zones[2][0] and value <= zones[2][1]:
-                frac3+=1
-            elif value > zones[1][0] and value <= zones[1][1]:
-                frac4+=1
-            elif value > zones[0][0] and value <= zones[0][1]:
-                frac5+=1
-            
-        fracs = []
-        explode=[]
-        if frac5 == 0:
-            labels.pop(5)
-            colors.pop(5)
-        else:
-            fracs.insert(0, frac5)
-            explode.insert(0, 0)
+        labels = [_("rest")]
+        colors = ["#ffffff"]
+        for zone in reversed(zones):
+            labels.append(zone[3])
+            colors.append(zone[2])
 
-        if frac4 == 0:
-            labels.pop(4)
-            colors.pop(4)
-        else:
-            fracs.insert(0, frac4)
-            explode.insert(0, 0)
-            
-        if frac3 == 0:
-            labels.pop(3)
-            colors.pop(3)
-        else:
-            fracs.insert(0, frac3)
-            explode.insert(0, 0)
-            
-        if frac2 == 0:
-            labels.pop(2)
-            colors.pop(2)
-        else:
-            fracs.insert(0, frac2)
-            explode.insert(0, 0)
-            
-        if frac1 == 0:
-            labels.pop(1)
-            colors.pop(1)
-        else:
-            fracs.insert(0, frac1)
-            explode.insert(0, 0)
-            
-        if frac0 == 0:
-            labels.pop(0)
-            colors.pop(0)
-        else:
-            fracs.insert(0, frac0)
-            explode.insert(0, 0)
-        axis.pie(fracs, explode=explode, labels=labels, colors=colors, autopct='%1.1f%%', shadow=True)
+        zone_sum = [0]*6
+        for value in yvalues[0]:
+            # bisection, it's faster
+            if value <= zones[2][1]:
+                if value <= zones[4][1]:
+                    if value <= zones[4][0]:
+                        zone_sum[0] += 1
+                    else:
+                        zone_sum[1] += 1
+                else:
+                    if value <= zones[3][1]:
+                        zone_sum[2] += 1
+                    else:
+                        zone_sum[3] += 1
+            else:
+                if value <= zones[1][1]:
+                    zone_sum[4] += 1
+                else:
+                    zone_sum[5] += 1
+
+        if shape == "pie":
+            self._piePlot(axis, zone_sum, colors, labels)
+        elif shape == "histogram":
+            self._barPlot(axis, zone_sum, colors, labels)
 
         canvas = FigureCanvasGTK(figure) # a gtk.DrawingArea
         canvas.show()
 
         for child in self.vbox.get_children():
-            logging.debug('Child available: '+str(child))
+            logging.debug('Child available: %s', child)
 
-        self.vbox.pack_start(canvas, True, True)
+        self.vbox.pack_start(canvas, True, True, 0)
         logging.debug('<<')
 
+    def _barPlot(self, axis, zone_sum, colors, labels):
+        invtotal = 100.0/sum(zone_sum)
+        fracs = [i*invtotal for i in zone_sum]
+        xticks = list(range(len(fracs)))
+
+        axis.bar(xticks, fracs, color=colors, align="center")
+        axis.set_xticks(xticks)
+        axis.set_xticklabels(labels)
+        axis.set_ylabel(_("Time in zone [%]"))
+
+    def _piePlot(self, axis, zone_sum, colors, labels):
+        labels_trunc = [l for z,l in zip(zone_sum, labels) if z > 0]
+        colors_trunc = [c for z,c in zip(zone_sum, colors) if z > 0]
+        zone_trunc   = [z for z in zone_sum if z > 0]
+        explode      = [0]*len(zone_trunc)
+        axis.pie(zone_trunc, explode=explode, labels=labels_trunc, colors=colors_trunc, autopct='%1.1f%%', shadow=True)
+
     def drawDefault(self):
         logging.debug('>>')
         self.axis=self.figure.add_subplot(111)
@@ -488,7 +464,7 @@ class DrawArea:
         self.canvas.destroy()
         self.canvas = FigureCanvasGTK(self.figure) # a gtk.DrawingArea
         self.canvas.show()
-        self.vbox.pack_start(self.canvas, True, True)
+        self.vbox.pack_start(self.canvas, True, True, 0)
         logging.debug('<<')
 
     def fill_over(self, ax, x, y, val, color, over=True):
@@ -521,13 +497,13 @@ class DrawArea:
             there must a better way to do this - pyplot?
         '''
         logging.debug('>>')
-        #Tidy up draw areas 
+        #Tidy up draw areas
         vboxChildren = self.vbox.get_children()
-        logging.debug('Vbox has %d children %s' % (len(vboxChildren), str(vboxChildren) ))
+        logging.debug('Vbox has %d children %s', len(vboxChildren), vboxChildren)
         # ToDo: check why vertical container is shared
         for child in vboxChildren:
             #Remove all FigureCanvasGTK and NavigationToolbar2GTKAgg to stop double ups of graphs
-            if isinstance(child, matplotlib.backends.backend_gtkagg.FigureCanvasGTK) or isinstance(child, matplotlib.backends.backend_gtkagg.NavigationToolbar2GTKAgg):
-                logging.debug('Removing child: '+str(child))
+            if isinstance(child, FigureCanvasGTK) or isinstance(child, NavigationToolbar):
+                logging.debug('Removing child: %s', child)
                 self.vbox.remove(child)
         logging.debug('<<')
