@@ -16,10 +16,11 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-import gtk
+from gi.repository import Gtk
 from pytrainer.core.equipment import Equipment
+from pytrainer.lib.localization import gtk_str
 
-class EquipmentStore(gtk.ListStore):
+class EquipmentStore(Gtk.ListStore):
     
     def __init__(self, equipment_service):
         super(EquipmentStore, self).__init__(int, str, float, str, bool)
@@ -27,9 +28,9 @@ class EquipmentStore(gtk.ListStore):
         for equipment in equipment_service.get_all_equipment():
             self._append_row(equipment)
         self.set_default_sort_func(self._sort)
-        self.set_sort_column_id(-1, gtk.SORT_ASCENDING)
+        self.set_sort_column_id(-1, Gtk.SortType.ASCENDING)
         
-    def _sort(self, store, x, y):
+    def _sort(self, store, x, y, user_data):
         if self.get_value(x, 4) != self.get_value(y, 4):
             return self.get_value(y, 4)-self.get_value(x, 4)
         elif self.get_value(x, 2) == self.get_value(y, 2):
@@ -75,12 +76,12 @@ class EquipmentStore(gtk.ListStore):
         self._equipment_service.remove_equipment(item)
         self.remove(self.get_iter(item_path))
 
-class EquipmentUi(gtk.HBox):
+class EquipmentUi(Gtk.HBox):
     
     def __init__(self, glade_conf_dir, equipment_service):
-        gtk.HBox.__init__(self)
+        super(EquipmentUi, self).__init__()
         self._equipment_store = EquipmentStore(equipment_service)
-        self._builder = gtk.Builder()
+        self._builder = Gtk.Builder()
         self._builder.add_from_file(glade_conf_dir + "/equipment.ui")
         self._init_tree_view()
         self._init_signals()
@@ -95,13 +96,13 @@ class EquipmentUi(gtk.HBox):
 
     def _init_tree_view(self):
         tree_view = self._get_tree_view()
-        column = gtk.TreeViewColumn(_("Description"), gtk.CellRendererText(), text=1)
+        column = Gtk.TreeViewColumn(_("Description"), Gtk.CellRendererText(), text=1)
         column.set_resizable(True)
         tree_view.append_column(column)
-        tree_view.append_column(gtk.TreeViewColumn(_("Usage"), gtk.CellRendererProgress(), value=2, text=3))
-        tree_view.append_column(gtk.TreeViewColumn(_("Active"), gtk.CellRendererToggle(), active=4))
+        tree_view.append_column(Gtk.TreeViewColumn(_("Usage"), Gtk.CellRendererProgress(), value=2, text=3))
+        tree_view.append_column(Gtk.TreeViewColumn(_("Active"), Gtk.CellRendererToggle(), active=4))
         # add filler column
-        tree_view.append_column(gtk.TreeViewColumn())
+        tree_view.append_column(Gtk.TreeViewColumn())
         tree_view.set_model(self._equipment_store)
         
     def _init_signals(self):
@@ -154,18 +155,19 @@ class EquipmentUi(gtk.HBox):
     
     def _confirm_add_equipment_clicked(self, widget):
         #FIXME input validation for numeric fields
-        description = self._builder.get_object("entryEquipmentAddDescription").get_text()
-        life_expectancy = self._builder.get_object("entryEquipmentAddLifeExpectancy").get_text()
-        prior_usage = self._builder.get_object("entryEquipmentAddPriorUsage").get_text()
+        description = gtk_str(self._builder.get_object("entryEquipmentAddDescription").get_text())
+        life_expectancy = gtk_str(self._builder.get_object("entryEquipmentAddLifeExpectancy").get_text())
+        prior_usage = gtk_str(self._builder.get_object("entryEquipmentAddPriorUsage").get_text())
         active = self._builder.get_object("checkbuttonEquipmentAddActive").get_active()
         notes_buffer = self._builder.get_object("textviewEquipmentAddNotes").get_buffer()
-        notes = notes_buffer.get_text(notes_buffer.get_start_iter(), notes_buffer.get_end_iter())
+        notes = gtk_str(notes_buffer.get_text(notes_buffer.get_start_iter(),
+                                              notes_buffer.get_end_iter(), True))
         new_equipment = Equipment()
-        new_equipment.description = unicode(description)
-        new_equipment.active = active
-        new_equipment.life_expectancy = life_expectancy
-        new_equipment.prior_usage = prior_usage
-        new_equipment.notes = unicode(notes)
+        new_equipment.description = description
+        new_equipment.active = bool(active)
+        new_equipment.life_expectancy = int(life_expectancy)
+        new_equipment.prior_usage = int(prior_usage)
+        new_equipment.notes = notes
         self._equipment_store.add_equipment(new_equipment)
         self.show_page_equipment_list()
         
@@ -189,14 +191,15 @@ class EquipmentUi(gtk.HBox):
         
     def _confirm_edit_equipment_clicked(self, widget):
         item = self._get_selected_equipment_item()
-        description_text = self._builder.get_object("entryEquipmentEditDescription").get_text()
-        item.description = unicode(description_text)
-        item.life_expectancy = self._builder.get_object("entryEquipmentEditLifeExpectancy").get_text()
-        item.prior_usage = self._builder.get_object("entryEquipmentEditPriorUsage").get_text()
+        description_text = gtk_str(self._builder.get_object("entryEquipmentEditDescription").get_text())
+        item.description = description_text
+        item.life_expectancy = gtk_str(self._builder.get_object("entryEquipmentEditLifeExpectancy").get_text())
+        item.prior_usage = gtk_str(self._builder.get_object("entryEquipmentEditPriorUsage").get_text())
         item.active = self._builder.get_object("checkbuttonEquipmentEditActive").get_active()
         notes_buffer = self._builder.get_object("textviewEquipmentEditNotes").get_buffer()
-        notes_text = notes_buffer.get_text(notes_buffer.get_start_iter(), notes_buffer.get_end_iter())
-        item.notes = unicode(notes_text)
+        notes_text = gtk_str(notes_buffer.get_text(notes_buffer.get_start_iter(),
+                                                   notes_buffer.get_end_iter(), True))
+        item.notes = notes_text
         self._equipment_store.edit_equipment(self._get_selected_equipment_path(), item)
         self.show_page_equipment_list()
     
