@@ -17,12 +17,12 @@
 #Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 from pytrainer.gui.dialogs import warning_dialog
-import gtk
-import logging
+from gi.repository import Gtk
+import warnings
 
 class Warning(object):
     def __init__(self, data_path = None, okmethod = None, okparams = None, cancelmethod = None, cancelparams = None):
-        logging.warning("Deprecated Warning class called")
+        warnings.warn("Deprecated Warning class called", DeprecationWarning, stacklevel=2)
         self.okmethod = okmethod
         self.cancelmethod = cancelmethod
         self.okparams = okparams
@@ -61,7 +61,7 @@ class Warning(object):
             response = warning_dialog(text=self.text, title=self.title, cancel=True)
         else:
             response = warning_dialog(text=self.text, title=self.title, cancel=False)
-        if response == gtk.RESPONSE_OK:
+        if response == Gtk.ResponseType.OK:
             self.on_accept_clicked()
-        elif response == gtk.RESPONSE_CANCEL:
+        elif response == Gtk.ResponseType.CANCEL:
             self.on_cancel_clicked()
