@@ -1,20 +1,21 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-from SimpleGladeApp import SimpleBuilderApp
-import gtk
-import gobject
+from .SimpleGladeApp import SimpleBuilderApp
+from gi.repository import Gtk
+from gi.repository import GObject
 import os, glob, sys
-import StringIO
 import logging
 import types
-from lxml import etree
 import csv
 import locale
 
 from pytrainer.plugins import Plugins
 from pytrainer.gui.dialogs import fileChooserDialog
 from pytrainer.lib.date import getDateTime
+from pytrainer.core.activity import Activity
+from pytrainer.lib.localization import gtk_str
+
 
 class WindowImportdata(SimpleBuilderApp):
     def __init__(self, sport_service, data_path = None, parent=None, config=None, pytrainer_main=None):
@@ -23,8 +24,8 @@ class WindowImportdata(SimpleBuilderApp):
         self.parent = parent
         self.pytrainer_main = pytrainer_main
         self.configuration = config
-        self.activities_store = None # gtk.ListStore containing gtk.TreeModelRow, see build_activities_tree_view
-        self.files_store = None # gtk.ListStore containing gtk.TreeModelRow, see build_files_tree_view
+        self.activities_store = None # Gtk.ListStore containing Gtk.TreeModelRow, see build_activities_tree_view
+        self.files_store = None # Gtk.ListStore containing Gtk.TreeModelRow, see build_files_tree_view
         self.processClasses = []
         self.plugins = Plugins(data_path, self.parent.parent)
         SimpleBuilderApp.__init__(self, "importdata.ui")
@@ -42,7 +43,7 @@ class WindowImportdata(SimpleBuilderApp):
             self.auto_launch = True
         else:
             self.auto_launch = False
-        logging.debug("Default tab: %s, Auto launch: %s" % (str(self.defaulttab), str(self.auto_launch)))
+        logging.debug("Default tab: %s, Auto launch: %s", self.defaulttab, self.auto_launch)
         self.init_all_tabs()
         self.notebookMainTabs.set_current_page(self.defaulttab)
         self.init_tab(self.defaulttab, first=True)          #TODO fix so dont need to re-call init_tab
@@ -106,8 +107,8 @@ class WindowImportdata(SimpleBuilderApp):
         self.buttonRemoveSelectedFiles.set_sensitive(0)
         self.buttonFileImport.set_sensitive(0)
         if first and self.auto_launch:
-            while gtk.events_pending(): # This allows the GUI to update
-                gtk.main_iteration()    # before completion of this entire action
+            while Gtk.events_pending(): # This allows the GUI to update
+                Gtk.main_iteration()    # before completion of this entire action
             logging.debug("autolaunch active")
             self.buttonSelectFiles.clicked()
         logging.debug(">>")
@@ -117,7 +118,7 @@ class WindowImportdata(SimpleBuilderApp):
         logging.debug(">>")
         #Remove components in vbox - in case of re-detection
         for child in self.vboxPlugins.get_children():
-            if isinstance(child, gtk.Table):
+            if isinstance(child, Gtk.Table):
                 self.vboxPlugins.remove(child)
         pluginList = self.plugins.getPluginsList()
         logging.debug(pluginList)
@@ -127,10 +128,10 @@ class WindowImportdata(SimpleBuilderApp):
             pluginName = plugin[1]
             pluginDescription = plugin[2]
             #Build frame with name and description
-            pluginFrame = gtk.Frame(label="<b>"+pluginName+"</b>")
+            pluginFrame = Gtk.Frame(label="<b>"+pluginName+"</b>")
             pluginFrameLabel = pluginFrame.get_label_widget()
             pluginFrameLabel.set_use_markup(True)
-            description = gtk.Label("<small>"+pluginDescription+"</small>")
+            description = Gtk.Label(label="<small>"+pluginDescription+"</small>")
             description.set_alignment(0,0)
             description.set_use_markup(True)
             description.set_line_wrap(True)
@@ -138,21 +139,21 @@ class WindowImportdata(SimpleBuilderApp):
             #Get plugin information
             name,description,status = self.plugins.getPluginInfo(pluginClass)
             #Create labels and buttons
-            configButton = gtk.Button(label=_("Configure"))
+            configButton = Gtk.Button(label=_("Configure"))
             #Connect button handlers
             configButton.connect('clicked', self.on_pluginsButton_Configure_clicked, pluginClass)
             if status == 0 or status == "0":
                 #Plugin disabled
                 pluginFrame.set_sensitive(0)
-                statusLabel = gtk.Label(_("Disabled"))
+                statusLabel = Gtk.Label(label=_("Disabled"))
             else:
-                statusLabel = gtk.Label(_("Enabled"))
+                statusLabel = Gtk.Label(label=_("Enabled"))
 
             #Create a table for the frame and button
-            pluginTable = gtk.Table()
-            pluginTable.attach(pluginFrame, 0, 1, 0, 1, xoptions=gtk.EXPAND|gtk.FILL, xpadding=5)
-            pluginTable.attach(statusLabel, 1, 2, 0, 1, xoptions=gtk.FILL, yoptions=gtk.SHRINK, xpadding=5, ypadding=5)
-            pluginTable.attach(configButton, 2, 3, 0, 1, xoptions=gtk.FILL, yoptions=gtk.SHRINK, xpadding=5, ypadding=5)
+            pluginTable = Gtk.Table()
+            pluginTable.attach(pluginFrame, 0, 1, 0, 1, xoptions=Gtk.AttachOptions.EXPAND|Gtk.AttachOptions.FILL, xpadding=5)
+            pluginTable.attach(statusLabel, 1, 2, 0, 1, xoptions=Gtk.AttachOptions.FILL, yoptions=Gtk.AttachOptions.SHRINK, xpadding=5, ypadding=5)
+            pluginTable.attach(configButton, 2, 3, 0, 1, xoptions=Gtk.AttachOptions.FILL, yoptions=Gtk.AttachOptions.SHRINK, xpadding=5, ypadding=5)
             #Add frame to tab
             self.vboxPlugins.pack_start(pluginTable, expand=False, fill=False, padding=5)
         self.win_importdata.show_all()
@@ -161,7 +162,7 @@ class WindowImportdata(SimpleBuilderApp):
 
     def init_options_tab(self):
         logging.debug(">>")
-        logging.debug("Default tab %s" % str(self.defaulttab) )
+        logging.debug("Default tab %s", self.defaulttab)
         #Set correct radiobutton based on saved preference
         if self.defaulttab == 1:
             self.radiobuttonFile.set_active(1)
@@ -180,7 +181,7 @@ class WindowImportdata(SimpleBuilderApp):
         #Populate Force Sport to combobox
         sport_list = self._sport_service.get_all_sports()
         #Remove placeholder item (needed to ensure correct model for combobox)
-        self.comboCSVForceSport.remove_text(0)
+        self.comboCSVForceSport.remove(0)
         for sport in sport_list:
             logging.debug('Adding sport: %s' % sport.name)
             self.comboCSVForceSport.append_text(sport.name)
@@ -211,36 +212,36 @@ class WindowImportdata(SimpleBuilderApp):
             filename = filename.rstrip('.py')
             classname = filename.lstrip('tool_')
             #Import module
-            sys.path.insert(0, self.data_path+"import")
+            sys.path.insert(0, os.path.join(self.data_path, "imports"))
             module = __import__(filename)
             toolMain = getattr(module, classname)
             #Instantiate module
             toolClass = toolMain(self.parent, self.data_path)
             #Get info from class
             toolName = toolClass.getName()
-            toolTable = gtk.Table()
-            toolFrame = gtk.Frame(label=toolName)
+            toolTable = Gtk.Table()
+            toolFrame = Gtk.Frame(label=toolName)
             toolFrame.add(toolTable)
             if toolClass.isPresent():
-                version = gtk.Label("Version: " + toolClass.getVersion())
+                version = Gtk.Label(label="Version: " + toolClass.getVersion())
                 version.set_alignment(0,0)
                 if toolClass.deviceExists():
-                    deviceExists = gtk.Label(_("GPS device found") )
+                    deviceExists = Gtk.Label(label=_("GPS device found") )
                     deviceExists.set_alignment(0,0)
                 else:
-                    deviceExists = gtk.Label(_("GPS device <b>not</b> found"))
+                    deviceExists = Gtk.Label(label=_("GPS device <b>not</b> found"))
                     deviceExists.set_alignment(0,0)
                     deviceExists.set_use_markup(True)
-                toolTable.attach(version, 0, 1, 0, 1, xoptions=gtk.EXPAND|gtk.FILL, xpadding=5)
-                toolTable.attach(deviceExists, 0, 1, 1, 2, xoptions=gtk.EXPAND|gtk.FILL, xpadding=5)
+                toolTable.attach(version, 0, 1, 0, 1, xoptions=Gtk.AttachOptions.EXPAND|Gtk.AttachOptions.FILL, xpadding=5)
+                toolTable.attach(deviceExists, 0, 1, 1, 2, xoptions=Gtk.AttachOptions.EXPAND|Gtk.AttachOptions.FILL, xpadding=5)
                 toolFrame.set_sensitive(1)
             else:
-                info = gtk.Label(_("This tool was not found on the system") )
+                info = Gtk.Label(label=_("This tool was not found on the system") )
                 info.set_alignment(0,0.5)
-                location = gtk.LinkButton(toolClass.getSourceLocation(), toolName +_(" Homepage"))
+                location = Gtk.LinkButton(toolClass.getSourceLocation(), toolName +_(" Homepage"))
                 info.set_sensitive(0)
-                toolTable.attach(info, 0, 1, 0, 1, xoptions=gtk.EXPAND|gtk.FILL, xpadding=5)
-                toolTable.attach(location, 1, 2, 0, 1, xoptions=gtk.EXPAND|gtk.FILL, xpadding=5)
+                toolTable.attach(info, 0, 1, 0, 1, xoptions=Gtk.AttachOptions.EXPAND|Gtk.AttachOptions.FILL, xpadding=5)
+                toolTable.attach(location, 1, 2, 0, 1, xoptions=Gtk.AttachOptions.EXPAND|Gtk.AttachOptions.FILL, xpadding=5)
                 #toolFrame.set_sensitive(0)
             self.vboxImportTools.pack_start(toolFrame, expand=False, fill=False, padding=5)
         self.win_importdata.show_all()
@@ -285,24 +286,24 @@ class WindowImportdata(SimpleBuilderApp):
     def build_files_tree_view(self):
         ''' Build tree view to hold files from which the activities are read '''
         logging.debug('>>')
-        store = gtk.ListStore(  gobject.TYPE_STRING,
-                                gobject.TYPE_BOOLEAN,
-                                gobject.TYPE_STRING,
-                                gobject.TYPE_STRING,
-                                gobject.TYPE_STRING, )
+        store = Gtk.ListStore(  GObject.TYPE_STRING,
+                                GObject.TYPE_BOOLEAN,
+                                GObject.TYPE_STRING,
+                                GObject.TYPE_STRING,
+                                GObject.TYPE_STRING, )
         column_names=["id", "", _("File"), _("Type"), _("Activities")]
         for column_index, column_name in enumerate(column_names):
             if column_index == 1:
                 #Add button column
-                self.renderer1 = gtk.CellRendererToggle()
+                self.renderer1 = Gtk.CellRendererToggle()
                 self.renderer1.set_property('activatable', True)
                 self.renderer1.connect( 'toggled', self.treeviewImportFiles_toggled_checkbox, store )
-                column = gtk.TreeViewColumn(column_name, self.renderer1 )
+                column = Gtk.TreeViewColumn(column_name, self.renderer1 )
                 column.add_attribute( self.renderer1, "active", column_index)
                 column.set_sort_column_id(-1)
             else:
                 #Add other columns
-                column = gtk.TreeViewColumn(column_name, gtk.CellRendererText(), text=column_index)
+                column = Gtk.TreeViewColumn(column_name, Gtk.CellRendererText(), text=column_index)
                 column.set_sort_column_id(column_index)
             if column_name == "id":
                 column.set_visible(False)
@@ -316,29 +317,29 @@ class WindowImportdata(SimpleBuilderApp):
     def build_activities_tree_view(self):
         ''' Build tree view to hold activities that can be selected for import '''
         logging.debug('>>')
-        store = gtk.ListStore(  gobject.TYPE_STRING,
-                                gobject.TYPE_BOOLEAN,
-                                gobject.TYPE_STRING,
-                                gobject.TYPE_STRING,
-                                gobject.TYPE_STRING,
-                                gobject.TYPE_STRING,
-                                gobject.TYPE_STRING,
-                                gobject.TYPE_STRING,
-                                gobject.TYPE_BOOLEAN )
+        store = Gtk.ListStore(  GObject.TYPE_STRING,
+                                GObject.TYPE_BOOLEAN,
+                                GObject.TYPE_STRING,
+                                GObject.TYPE_STRING,
+                                GObject.TYPE_STRING,
+                                GObject.TYPE_STRING,
+                                GObject.TYPE_STRING,
+                                GObject.TYPE_STRING,
+                                GObject.TYPE_BOOLEAN )
         column_names=["id", "", _("Start Time"), _("Distance"), _("Duration"), _("Sport"), _("Notes"), "file_id", "in_db"]
         for column_index, column_name in enumerate(column_names):
             if column_index == 1:
                 #Add checkbox column
-                self.renderer1 = gtk.CellRendererToggle()
+                self.renderer1 = Gtk.CellRendererToggle()
                 self.renderer1.set_property('activatable', True)
                 self.renderer1.connect( 'toggled', self.treeviewImportEvents_toggled_checkbox, store )
-                column = gtk.TreeViewColumn(column_name, self.renderer1 )
+                column = Gtk.TreeViewColumn(column_name, self.renderer1 )
                 column.add_attribute( self.renderer1, "active", column_index)
                 column.set_sort_column_id(-1)
                 column.connect('clicked', self.treeviewImportEvents_header_checkbox, store)
             else:
                 #Add other columns
-                column = gtk.TreeViewColumn(column_name, gtk.CellRendererText(), text=column_index)
+                column = Gtk.TreeViewColumn(column_name, Gtk.CellRendererText(), text=column_index)
                 column.set_sort_column_id(column_index)
             if column_name == "id" or column_name == "file_id" or column_name == "in_db":
                 column.set_visible(False)
@@ -401,7 +402,7 @@ class WindowImportdata(SimpleBuilderApp):
                 self.autoLaunchFileSelection = "True"
         elif self.radiobuttonPlugins.get_active():
             self.defaulttab = "2"
-        logging.debug("Saving default tab: %s, auto launch: %s" % (str(self.defaulttab), str(self.autoLaunchFileSelection)))
+        logging.debug("Saving default tab: %s, auto launch: %s", self.defaulttab, self.autoLaunchFileSelection)
         self.configuration.setValue("pytraining","import_default_tab",self.defaulttab)
         self.configuration.setValue("pytraining","auto_launch_file_selection",self.autoLaunchFileSelection)
 
@@ -474,7 +475,7 @@ class WindowImportdata(SimpleBuilderApp):
             logging.debug("Importing %d activities" % len(activities))
             result = self.pytrainer_main.record.newMultiRecord(activities)
             for activity in result:
-                if "db_id" in activity.keys() and type(activity["db_id"]) is types.IntType:
+                if "db_id" in activity.keys() and type(activity["db_id"]) is int:
                     #Activity imported correctly
                     duration = "%0.0f:%0.0f:%02.0f" % (float(activity["rcd_time"][0]), float(activity["rcd_time"][1]), float(activity["rcd_time"][2]))
                     self.updateActivity(activity["activity_id"], 
@@ -517,7 +518,7 @@ class WindowImportdata(SimpleBuilderApp):
     ############################
 
     def on_radiobuttonFile_toggled(self, *args):
-        print "radio button toggled"
+        logging.debug("radio button toggled")
 
     def on_pluginsButton_Configure_clicked(self, button, pluginClass):
         '''
@@ -526,23 +527,24 @@ class WindowImportdata(SimpleBuilderApp):
         name,description,status = self.plugins.getPluginInfo(pluginClass)
         prefs = self.plugins.getPluginConfParams(pluginClass)
 
-        self.prefwindow = gtk.Window()
+        self.prefwindow = Gtk.Window()
         self.prefwindow.set_border_width(20)
         self.prefwindow.set_title(_("%s settings" %name))
+        self.prefwindow.set_modal(True)
 
-        table = gtk.Table(1,2)
+        table = Gtk.Table(1,2)
         i=0
         self.entryList = []
         for pref in prefs:
-            label = gtk.Label("<b>%s</b>"%pref[0])
+            label = Gtk.Label(label="<b>%s</b>"%pref[0])
             label.set_use_markup(True)
             if pref[0] != "status":
-                entry = gtk.Entry()
+                entry = Gtk.Entry()
                 entry.set_text(pref[1])
                 self.entryList.append(entry)
                 table.attach(entry,1,2,i,i+1)
             else:
-                combobox = gtk.combo_box_new_text()
+                combobox = Gtk.ComboBoxText()
                 combobox.append_text(_("Disable"))
                 combobox.append_text(_("Enable"))
                 combobox.set_active(int(pref[1]))
@@ -551,7 +553,7 @@ class WindowImportdata(SimpleBuilderApp):
             table.attach(label,0,1,i,i+1)
             i+=1
 
-        button = gtk.Button(_("Ok"))
+        button = Gtk.Button(_("Ok"))
         button.connect("clicked", self.on_pluginAcceptSettings_clicked, pluginClass)
         table.attach(button,0,2,i,i+1)
         self.prefwindow.add(table)
@@ -567,7 +569,7 @@ class WindowImportdata(SimpleBuilderApp):
         i = 0
         for pref in prefs:
             try:
-                savedOptions.append((pref[0],self.entryList[i].get_text()))
+                savedOptions.append((pref[0], gtk_str(self.entryList[i].get_text())))
             except:
                 combobox = self.entryList[i]
                 index = combobox.get_active()
@@ -636,8 +638,8 @@ class WindowImportdata(SimpleBuilderApp):
                 msgImporting = _("Importing %d activities") % selectedCount
             self.updateStatusbar(self.statusbarImportFile, msgImporting)
             logging.debug(msgImporting)
-            while gtk.events_pending(): # This allows the GUI to update
-                gtk.main_iteration()    # before completion of this entire action
+            while Gtk.events_pending(): # This allows the GUI to update
+                Gtk.main_iteration()    # before completion of this entire action
             importedActivities = self.importSelectedActivities(selectedActivities)
             # Preparing feedback for user
             if importedActivities == 0:
@@ -660,8 +662,8 @@ class WindowImportdata(SimpleBuilderApp):
     def on_buttonSelectFiles_clicked(self, widget):
         logging.debug('>>')
         selectedFiles = fileChooserDialog(title=_("Choose a file (or files) to import activities from"), multiple=True).getFiles()
-        while gtk.events_pending(): # This allows the GUI to update
-            gtk.main_iteration()    # before completion of this entire action
+        while Gtk.events_pending(): # This allows the GUI to update
+            Gtk.main_iteration()    # before completion of this entire action
         if selectedFiles is None or len(selectedFiles) == 0:
             #Nothing selected
             logging.debug("No files selected")
@@ -678,16 +680,16 @@ class WindowImportdata(SimpleBuilderApp):
                 logging.debug("Found file of type: %s" % filetype)
                 activitiesSummary = self.processClasses[class_index].getActivitiesSummary()
                 activity_count = len(activitiesSummary)
-                logging.debug("%s activities in file: %s" % (str(activity_count), filename) )
+                logging.debug("%s activities in file: %s", activity_count, filename)
                 #Add file to files treeview
                 iter = self.files_store.append()
                 self.files_store.set(
                     iter,
-                    0, class_index,
+                    0, str(class_index),
                     1, True,
                     2, filename,
                     3, self.processClasses[class_index].getFileType(),
-                    4, activity_count
+                    4, str(activity_count)
                     )
                 #File valid, so enable remove button
                 self.buttonRemoveSelectedFiles.set_sensitive(1)
@@ -704,21 +706,21 @@ class WindowImportdata(SimpleBuilderApp):
                     # Status (#1) can be changed by user (via checkbox), we need another field to know if activity is in DB 
                     self.activities_store.set(
                         activity_iter,
-                        0, activity[0],
+                        0, str(activity[0]),
                         1, not activity[1],
                         2, activity[2],
                         3, activity[3],
                         4, activity[4],
                         5, activity[5],
                         6, note,
-                        7, class_index,
-                        8, activity [1],
+                        7, str(class_index),
+                        8, activity[1],
                         )
             else: #Selected file not understood by any of the process files
                 #Display error
                 logging.debug("File %s is of unknown or unsupported file type" % filename)
                 msg = _("File %s is of unknown or unsupported file type") % filename
-                md = gtk.MessageDialog(self.win_importdata, gtk.DIALOG_DESTROY_WITH_PARENT, gtk.MESSAGE_ERROR, gtk.BUTTONS_CLOSE, msg)
+                md = Gtk.MessageDialog(self.win_importdata, Gtk.DialogFlags.DESTROY_WITH_PARENT, Gtk.MessageType.ERROR, Gtk.ButtonsType.CLOSE, msg)
                 md.set_title("Error")
                 md.run()
                 md.destroy()
@@ -771,7 +773,7 @@ class WindowImportdata(SimpleBuilderApp):
         elif self.rbCSVComma.get_active():
             self.delimiter = ","
         elif self.rbCSVOther.get_active():
-            self.delimiter = self.entryCSVOther.get_text()
+            self.delimiter = gtk_str(self.entryCSVOther.get_text())
         else:
             self.delimiter = " "
 
@@ -790,7 +792,7 @@ class WindowImportdata(SimpleBuilderApp):
             columns = reader.fieldnames
         else:
             #Otherwise just label them with numbers
-            print len(reader.fieldnames)
+            logging.debug(len(reader.fieldnames))
             columns = [_("Column %d") % x for x in range(0, len(reader.fieldnames))]
 
         for column in columns:
@@ -866,23 +868,23 @@ class WindowImportdata(SimpleBuilderApp):
                 continue
             if not row:
                 continue
-            data = {}
+            data = Activity()
             #Determine dates
             _date = getDateTime(row[dateCol-1])
             #year, month, day = date.split("-")
             date = _date[1].strftime("%Y-%m-%d")
             zuluDateTime = _date[0].strftime("%Y-%m-%dT%H:%M:%SZ")
             localDateTime = str(_date[1])
-            data['date'] = date
-            data['date_time_utc'] = zuluDateTime
-            data['date_time_local'] = localDateTime
+            data.date = _date[1].date()
+            data.date_time_utc = zuluDateTime
+            data.date_time_local = localDateTime
             if distanceCol:
                 try:
-                    data['distance'] = locale.atof(row[distanceCol-1])
+                    data.distance = locale.atof(row[distanceCol-1])
                 except:
-                    data['distance'] = 0
+                    data.distance = 0
             else:
-                data['distance'] = 0
+                data.distance = 0
             if durationCol:
                 #calculate duration in sec...
                 try:
@@ -905,80 +907,82 @@ class WindowImportdata(SimpleBuilderApp):
                         logging.debug("Could not determine duration for '%s'" % _duration)
                         durationSec = None
                 if durationSec is not None:
-                    data['duration'] = durationSec
-                    data['time'] = str(durationSec)
+                    data.duration = durationSec
+                    data.time = str(durationSec)
             if titleCol:
                 try:
-                    data['title'] = row[titleCol-1]
+                    data.title = row[titleCol-1]
                 except:
                     pass
             if self.checkbCSVForceSport.get_active():
-                sport_id = self.pytrainer_main.record.getSportId(self.comboCSVForceSport.get_active_text(),add=True)
-                data['sport'] = sport_id
+                sport = self.pytrainer_main.record.getSport(
+                    gtk_str(self.comboCSVForceSport.get_active_text()), add=True)
+                data.sport = sport
             elif sportCol:
                 #retrieving sport id (adding sport if it doesn't exist yet)
-                sport_id = self.pytrainer_main.record.getSportId(row[sportCol-1],add=True)
-                data['sport'] = sport_id
+                sport = self.pytrainer_main.record.getSport(row[sportCol-1],add=True)
+                data.sport = sport
             else:
                 self.comboCSVForceSport.set_active(0)
-                sport_id = self.pytrainer_main.record.getSportId(self.comboCSVForceSport.get_active_text(),add=True)
-                data['sport'] = sport_id
+                sport = self.pytrainer_main.record.getSport(
+                    gtk_str(self.comboCSVForceSport.get_active_text()), add=True)
+                data.sport = sport
 
             if avgspeedCol:
                 #
                 try:
-                    data['average'] = locale.atof(row[avgspeedCol-1])
+                    data.average = locale.atof(row[avgspeedCol-1])
                 except:
                     pass
             if maxspeedCol:
                 try:
-                    data['maxspeed'] = locale.atof(row[maxspeedCol-1])
+                    data.maxspeed = locale.atof(row[maxspeedCol-1])
                 except:
                     pass
             if calCol:
                 try:
-                    data['calories'] = locale.atoi(row[calCol-1])
+                    data.calories = locale.atoi(row[calCol-1])
                 except:
                     pass
             if accCol:
                 try:
-                    data['upositive'] = locale.atof(row[accCol-1])
+                    data.upositive = locale.atof(row[accCol-1])
                 except:
                     pass
             if desCol:
                 try:
-                    data['unegative'] = locale.atof(row[desCol-1])
+                    data.unegative = locale.atof(row[desCol-1])
                 except:
                     pass
             if hrCol:
                 try:
-                    data['beats'] = locale.atof(row[hrCol-1])
+                    data.beats = locale.atof(row[hrCol-1])
                 except:
                     pass
             if maxHRCol:
                 try:
-                    data['maxbeats'] = locale.atof(row[maxHRCol-1])
+                    data.maxbeats = locale.atof(row[maxHRCol-1])
                 except:
                     pass
             if paceCol:
                 try:
-                    data['pace'] = locale.atof(row[paceCol-1])
+                    data.pace = locale.atof(row[paceCol-1])
                 except:
                     pass
             if maxPaceCol:
                 try:
-                    data['maxpace'] = locale.atof(row[maxPaceCol-1])
+                    data.maxpace = locale.atof(row[maxPaceCol-1])
                 except:
                     pass
             if commentsCol:
                 try:
-                    data['comments'] = row[commentsCol--1]
+                    data.comments = row[commentsCol--1]
                 except:
                     pass
 
             #Insert into DB
-            logging.debug("Data", data)
-            self.pytrainer_main.ddbb.insert_dict('records', data)
+            self.pytrainer_main.ddbb.session.add(data)
+            self.pytrainer_main.ddbb.session.commit()
         #Display message....
         self.updateStatusbar(self.statusbarCSVImport, _("Import completed. %d rows processed") % i)
         #Disable import button
