@@ -17,17 +17,19 @@
 #Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 from __future__ import division
-from SimpleGladeApp import SimpleBuilderApp
-from windowcalendar import WindowCalendar
+from .SimpleGladeApp import SimpleBuilderApp
+from .windowcalendar import WindowCalendar
 from pytrainer.core.equipment import EquipmentService
 from pytrainer.gui.equipment import EquipmentUi
 from pytrainer.core.sport import Sport
-import gtk
-import gobject
+from gi.repository import Gtk, GdkPixbuf
+from gi.repository import GObject
 import logging
 import pytrainer
 import pytrainer.util.color
 from pytrainer.gui.color import ColorConverter
+from pytrainer.gui.dialogs import warning_dialog
+from pytrainer.lib.localization import gtk_str
 
 class WindowProfile(SimpleBuilderApp):
     def __init__(self, sport_service, data_path = None, parent=None, pytrainer_main=None):
@@ -42,19 +44,20 @@ class WindowProfile(SimpleBuilderApp):
     def new(self):
         logging.debug(">>")
         self.gender_options = {
-            0:_("Male"),
-            1:_("Female")
+            0: "Male",
+            1: "Female"
             }
 
         self.ddbb_type = {
             0:"sqlite",
-            1:"mysql"
+            1:"mysql",
+            2:"postgresql",
             }
     
         #anhadimos las opciones al combobox gender
-        for i in self.gender_options:
-            self.prf_gender.insert_text(i,self.gender_options[i])
-        
+        for i, text in self.gender_options.items():
+            self.prf_gender.insert_text(i, _(text))
+
         #hacemos lo propio para el combobox ddbb 
         for i in self.ddbb_type:
             self.prf_ddbb.insert_text(i,self.ddbb_type[i])
@@ -63,15 +66,12 @@ class WindowProfile(SimpleBuilderApp):
         column_names=[_("Sport"),_("MET"),_("Extra Weight"), _("Maximum Pace"), _("Color")]
         for column_index, column_name in enumerate(column_names):
             if column_index==4:
-                renderer = gtk.CellRendererPixbuf()
-            else:
-                renderer = gtk.CellRendererText()
-            column = gtk.TreeViewColumn(column_name, text=column_index)
-            column.pack_start(renderer, expand=False)
-            if column_index==4:
+                renderer = Gtk.CellRendererPixbuf()
+                column = Gtk.TreeViewColumn(column_name, renderer)
                 column.add_attribute(renderer, 'pixbuf', column_index)
             else:
-                column.add_attribute(renderer, 'text', column_index)
+                renderer = Gtk.CellRendererText()
+                column = Gtk.TreeViewColumn(column_name, renderer, text=column_index)
             column.set_resizable(True)
             self.sportTreeView.append_column(column)
 
@@ -89,7 +89,7 @@ class WindowProfile(SimpleBuilderApp):
         # Need to think if it does make sense to use pprint -> compatibility issues
         #print list_options
         for i in self.conf_options.keys():
-            if not list_options.has_key(i):
+            if i not in list_options:
                 logging.info('No list options for %s' %s)
                 continue
             if i == "default_viewer":
@@ -115,9 +115,9 @@ class WindowProfile(SimpleBuilderApp):
                         logging.info("Setting %s to true" %i)
                         var.set_active(True)
                 elif i == "prf_gender":
-                    for j in self.gender_options:
-                        if self.gender_options[j] == list_options[i]:
-                            logging.info("Setting gender to %s" % self.gender_options[j])
+                    for j,label in self.gender_options.items():
+                        if label == list_options[i]:
+                            logging.info("Setting gender to %s" % label)
                             var.set_active(j)
                 elif i == "prf_ddbb":
                     for j in self.ddbb_type:
@@ -136,7 +136,7 @@ class WindowProfile(SimpleBuilderApp):
     def saveOptions(self):
         logging.debug(">>")
         list_options = {}
-        print self.conf_options
+        logging.debug(self.conf_options)
         for i in self.conf_options.keys():
             if i == "default_viewer":
                 if self.radiobuttonDefaultOSM.get_active():
@@ -158,10 +158,12 @@ class WindowProfile(SimpleBuilderApp):
                         list_options[i] = "True"
                     else:
                         list_options[i] = "False"
-                elif i == "prf_gender" or i == "prf_ddbb":
-                    list_options[i] = var.get_active_text()
+                elif i == "prf_gender":
+                    list_options[i] = self.gender_options[var.get_active()]
+                elif i == "prf_ddbb":
+                    list_options[i] = gtk_str(var.get_active_text())
                 else:
-                    list_options[i] = var.get_text()
+                    list_options[i] = gtk_str(var.get_text())
             logging.info("Saving %s as %s" % (i, list_options[i]))
         logging.info("Updating profile...")
         self.parent.setProfile(list_options)
@@ -180,16 +182,16 @@ class WindowProfile(SimpleBuilderApp):
         if frame==2:
             self.saveOptions()
             sport_list = self._sport_service.get_all_sports()
-            store = gtk.ListStore(
-                        gobject.TYPE_STRING,
-                        gobject.TYPE_STRING,
-                        gobject.TYPE_STRING,
-                        gobject.TYPE_STRING,
-                        gtk.gdk.Pixbuf,
+            store = Gtk.ListStore(
+                        GObject.TYPE_STRING,
+                        GObject.TYPE_FLOAT,
+                        GObject.TYPE_FLOAT,
+                        GObject.TYPE_FLOAT,
+                        GdkPixbuf.Pixbuf,
                         object)
             for sport in sport_list:
                 iter = store.append()
-                colorPixBuf = gtk.gdk.Pixbuf(gtk.gdk.COLORSPACE_RGB, False, 8, 25, 15)
+                colorPixBuf = GdkPixbuf.Pixbuf.new(GdkPixbuf.Colorspace.RGB, False, 8, 25, 15)
                 colorPixBuf.fill(sport.color.rgba_val)
                 store.set(iter,
                     0, sport.name,
@@ -215,7 +217,7 @@ class WindowProfile(SimpleBuilderApp):
             self.comboboxLogLevel.set_active(3)
         else:
             self.comboboxLogLevel.set_active(0)
-            print "Unknown logging level specified"
+            logging.error("Unknown logging level specified")
 
         #Show if validation requested
         if self.pytrainer_main.startup_options.validate:
@@ -294,28 +296,31 @@ class WindowProfile(SimpleBuilderApp):
         self.prf_ddbbpass.set_sensitive(0)
 
     def on_prf_ddbb_changed(self,widget):
-        i = self.prf_ddbb.get_active_text()
-        if i == "mysql":
-            self._ddbb_value_active()
-        else:
+        i = gtk_str(self.prf_ddbb.get_active_text())
+        if i == "sqlite":
             self._ddbb_value_deactive()
+        else:
+            self._ddbb_value_active()
 
     def on_addsport_clicked(self,widget):
         self.hidesportsteps()
         self.buttonbox.set_sensitive(0)
+        colorPixBuf = GdkPixbuf.Pixbuf.new(GdkPixbuf.Colorspace.RGB, False, 8, 250, 20)
+        colorPixBuf.fill(self.stored_color.rgba_val)
+        self.newcolor.set_from_pixbuf(colorPixBuf)
         self.addsport.show()
 
     def on_newsport_accept_clicked(self,widget):
         sport = Sport()
-        sport.name = unicode(self.newsportentry.get_text())
-        sport.met = self._trim_to_null(self.newmetentry.get_text())
-        sport.weight = self.newweightentry.get_text()
-        sport.max_pace = self._trim_to_null(self.newmaxpace.get_text())
+        sport.name = gtk_str(self.newsportentry.get_text())
+        sport.met = self._trim_to_null(gtk_str(self.newmetentry.get_text()))
+        sport.weight = self._float_or_zero(gtk_str(self.newweightentry.get_text()))
+        sport.max_pace = self._trim_to_null(gtk_str(self.newmaxpace.get_text()))
         sport.color = self.stored_color
         if sport.name.lower() in [s.name.lower() for s in self._sport_service.get_all_sports()]:
             msg = "Sport '%s' already exists" % sport.name
             logging.error(msg)
-            md = gtk.MessageDialog(None, gtk.DIALOG_DESTROY_WITH_PARENT, gtk.MESSAGE_ERROR, gtk.BUTTONS_CLOSE, _(msg))
+            md = Gtk.MessageDialog(None, Gtk.DialogFlags.DESTROY_WITH_PARENT, Gtk.MessageType.ERROR, Gtk.ButtonsType.CLOSE, _(msg))
             md.set_title(_("Sport Creation Error"))
             md.run()
             md.destroy()
@@ -337,7 +342,7 @@ class WindowProfile(SimpleBuilderApp):
             self.deletesport.show()
 
     def on_deletesport_clicked(self,widget):
-        sport_name = self.sportnamedel.get_text()
+        sport_name = gtk_str(self.sportnamedel.get_text())
         sport = self._sport_service.get_sport_by_name(sport_name)
         self._sport_service.remove_sport(sport)
         self.pytrainer_main.refreshMainSportList()
@@ -359,7 +364,7 @@ class WindowProfile(SimpleBuilderApp):
             self.editmetentry.set_text(met_str)
             max_pace_str = "" if sport.max_pace is None else str(sport.max_pace)
             self.editmaxpace.set_text(max_pace_str)
-            colorPixBuf = gtk.gdk.Pixbuf(gtk.gdk.COLORSPACE_RGB, False, 8, 250, 20)
+            colorPixBuf = GdkPixbuf.Pixbuf.new(GdkPixbuf.Colorspace.RGB, False, 8, 250, 20)
             colorPixBuf.fill(sport.color.rgba_val)
             self.editcolor.set_from_pixbuf(colorPixBuf)
             self.hidesportsteps()
@@ -370,13 +375,13 @@ class WindowProfile(SimpleBuilderApp):
         if iter:
             sport_desc = selected.get_value(iter,0)
             sport = self._sport_service.get_sport_by_name(sport_desc)
-            colorseldlg = gtk.ColorSelectionDialog("test")
-            colorseldlg.colorsel.set_has_palette(True)
-            colorseldlg.colorsel.set_current_color(ColorConverter().convert_to_gdk_color(sport.color))
+            colorseldlg = Gtk.ColorSelectionDialog("test")
+            colorseldlg.get_color_selection().set_has_palette(True)
+            colorseldlg.get_color_selection().set_current_color(ColorConverter().convert_to_gdk_color(sport.color))
             colorseldlg.run()
-            gdk_color = colorseldlg.colorsel.get_current_color()
+            gdk_color = colorseldlg.get_color_selection().get_current_color()
             self.stored_color = ColorConverter().convert_to_color(gdk_color)
-            colorPixBuf = gtk.gdk.Pixbuf(gtk.gdk.COLORSPACE_RGB, False, 8, 250, 20)
+            colorPixBuf = GdkPixbuf.Pixbuf.new(GdkPixbuf.Colorspace.RGB, False, 8, 250, 20)
             colorPixBuf.fill(self.stored_color.rgba_val)
             self.newcolor.set_from_pixbuf(colorPixBuf)
             self.editcolor.set_from_pixbuf(colorPixBuf)
@@ -387,12 +392,12 @@ class WindowProfile(SimpleBuilderApp):
         self.on_editsport_clicked(None)
     
     def on_editsport_accept_clicked(self,widget):
-        oldnamesport = self.sportnameedit.get_text()
+        oldnamesport = gtk_str(self.sportnameedit.get_text())
         sport = self._sport_service.get_sport_by_name(oldnamesport)
-        sport.name = unicode(self.editsportentry.get_text())
-        sport.weight = self.editweightentry.get_text()
-        sport.met = self._trim_to_null(self.editmetentry.get_text())
-        sport.max_pace = self._trim_to_null(self.editmaxpace.get_text())
+        sport.name = gtk_str(self.editsportentry.get_text())
+        sport.weight = self._float_or_zero(gtk_str(self.editweightentry.get_text()))
+        sport.met = self._trim_to_null(gtk_str(self.editmetentry.get_text()))
+        sport.max_pace = self._trim_to_null(gtk_str(self.editmaxpace.get_text()))
         sport.color = self.stored_color
         self._sport_service.store_sport(sport)
         self.pytrainer_main.refreshMainSportList()
@@ -404,6 +409,14 @@ class WindowProfile(SimpleBuilderApp):
     def _trim_to_null(self, string):
         trimmed = string.strip()
         return None if trimmed == "" else trimmed
+
+    @staticmethod
+    def _float_or_zero(string):
+        try:
+          return float(string)
+        except ValueError:
+          pass
+        return 0.0
         
     def on_sportcancel_clicked(self,widget):
         self.hidesportsteps()
@@ -414,8 +427,20 @@ class WindowProfile(SimpleBuilderApp):
         import datetime
         today = "%s"%datetime.date.today()
         year1,month1,day1 = today.split("-")
-        year2,month2,day2 = self.prf_age.get_text().split("-")
-        diff = datetime.datetime(int(year1), int(month1), int(day1),0,0,0) - datetime.datetime(int(year2), int(month2), int(day2),0,0,0)
+
+        # tell user that we can't calculate heart rate if age is not supplied
+        try:
+            year2, month2, day2 = gtk_str(self.prf_age.get_text()).split("-")
+            date1 = datetime.datetime(int(year1), int(month1), int(day1),0,0,0)
+            date2 = datetime.datetime(int(year2), int(month2), int(day2),0,0,0)
+        except ValueError:
+            msg = ("Unable to calculate max heart rate, please configure age "
+                   "in the <i>Athlete</i> tab.")
+            logging.error(msg)
+            warning_dialog(text=_(msg), title=_("Heart Rate Calculation Error"))
+            return
+
+        diff = date1 - date2
         self.prf_maxhr.set_text("%d" %(220-int(diff.days/365)))
 
     def hidesportsteps(self):
