@@ -20,14 +20,16 @@ from __future__ import division
 import os
 import logging
 import traceback
-import gtk, gobject
-from SimpleGladeApp import SimpleBuilderApp
-from windowcalendar import WindowCalendar
+from gi.repository import Gtk, GObject
+from pytrainer.gui.dialogs import warning_dialog
+from .SimpleGladeApp import SimpleBuilderApp
+from .windowcalendar import WindowCalendar
 
 from pytrainer.lib.date import getLocalTZ, time2second
 import dateutil.parser
 from dateutil.tz import tzutc
 from pytrainer.lib.uc import UC
+from pytrainer.lib.localization import gtk_str
 
 class WindowRecord(SimpleBuilderApp):
     def __init__(self, equipment_service, data_path = None, listSport = None, parent = None, date = None, title=None, distance=None, time=None, upositive=None, unegative=None, bpm=None, calories=None, comment=None, windowTitle=None, equipment=[]):
@@ -35,7 +37,7 @@ class WindowRecord(SimpleBuilderApp):
         self.parent = parent
         self.pytrainer_main = parent.pytrainer_main
         self.uc = UC()
-        logging.debug("Using US system: "+ str(self.uc.us))
+        logging.debug("Using US system: %s", self.uc.us)
         self.data_path = data_path
         self.mode = "newrecord"
         self.id_record = ""
@@ -109,14 +111,14 @@ class WindowRecord(SimpleBuilderApp):
             self.noActiveEquipmentMessageContainer.set_visible(True)
         for item in selected_equipment:
             equipment[item] = True
-        list_store = gtk.ListStore(int, str, bool)
+        list_store = Gtk.ListStore(int, str, bool)
         for item in equipment:
             list_store.append((item.id, item.description, equipment[item]))
         tree_view = self.treeviewRecordEquipment
-        cell_renderer = gtk.CellRendererToggle()
+        cell_renderer = Gtk.CellRendererToggle()
         cell_renderer.connect('toggled', self._equipment_selection_toggled)
-        tree_view.append_column(gtk.TreeViewColumn("Selected", cell_renderer, active=2))
-        tree_view.append_column(gtk.TreeViewColumn("Equipment Item", gtk.CellRendererText(), text=1))
+        tree_view.append_column(Gtk.TreeViewColumn("Selected", cell_renderer, active=2))
+        tree_view.append_column(Gtk.TreeViewColumn("Equipment Item", Gtk.CellRendererText(), text=1))
         tree_view.set_model(list_store)
     
     def _equipment_selection_toggled(self, widget, path):
@@ -173,7 +175,11 @@ class WindowRecord(SimpleBuilderApp):
             #details["rcd_time"] = (((float(hours) * 60) + float(mins)) * 60) + float(secs)
             details["activity_id"] = activity[0]
             details["rcd_time"] = (float(hours), float(mins), float(secs))
-            details["rcd_sport"] = activity[4]
+            if activity[4] is not None:
+                details["rcd_sport"] = activity[4]
+            else:
+                # No sport was provided, preliminary set the current selection from window
+                details["rcd_sport"] = gtk_str(self.rcd_sport.get_active_text())
             details["rcd_gpxfile"] = activity[5]
             details["file_id"] = activity[6]
             self.activity_data.append(details)
@@ -187,24 +193,24 @@ class WindowRecord(SimpleBuilderApp):
         self.button43.hide() #Pace "Calculate" button
         #Make GPX file 'unsensitive'
         self.rcd_gpxfile.set_sensitive(0)       
-        while gtk.events_pending(): # This allows the GUI to update 
-            gtk.main_iteration()    # before completion of this entire action
+        while Gtk.events_pending(): # This allows the GUI to update
+            Gtk.main_iteration()    # before completion of this entire action
         #Select first row and display details
         self.treeviewEntries.set_cursor(0)  
         self.show_treeviewEntries_row(0)
         logging.debug("<<")
         
     def build_tree_view(self):
-        store = gtk.ListStore(  gobject.TYPE_STRING,
-                                gobject.TYPE_STRING,
-                                gobject.TYPE_STRING,
-                                gobject.TYPE_STRING, 
-                                gobject.TYPE_STRING, 
-                                gobject.TYPE_STRING )
+        store = Gtk.ListStore(  GObject.TYPE_STRING,
+                                GObject.TYPE_STRING,
+                                GObject.TYPE_STRING,
+                                GObject.TYPE_STRING,
+                                GObject.TYPE_STRING,
+                                GObject.TYPE_STRING )
         column_names=["id", _("Start Time"), _("Distance"),_("Duration"),_("Sport"), _("GPX File")]
         for column_index, column_name in enumerate(column_names):
             #Add columns
-            column = gtk.TreeViewColumn(column_name, gtk.CellRendererText(), text=column_index)
+            column = Gtk.TreeViewColumn(column_name, Gtk.CellRendererText(), text=column_index)
             column.set_sort_column_id(column_index)
             if column_name == "id":
                 column.set_visible(False)
@@ -222,22 +228,22 @@ class WindowRecord(SimpleBuilderApp):
             if self.active_row is not None:
                 buffer = self.rcd_comments.get_buffer()
                 start,end = buffer.get_bounds()
-                comments = buffer.get_text(start,end, True).replace("\"","'")
+                comments = gtk_str(buffer.get_text(start,end, True))
                 self.activity_data[self.active_row]["rcd_comments"] = comments
                 #Advanced tab items
-                self.activity_data[self.active_row]["rcd_maxpace"] = self.rcd_maxpace.get_text()
-                self.activity_data[self.active_row]["rcd_pace"] = self.rcd_pace.get_text()
-                self.activity_data[self.active_row]["rcd_upositive"] = self.rcd_upositive.get_text()
-                self.activity_data[self.active_row]["rcd_unegative"] = self.rcd_unegative.get_text()
-                self.activity_data[self.active_row]["rcd_maxbeats"] = self.rcd_maxbeats.get_text()
-                self.activity_data[self.active_row]["rcd_beats"] = self.rcd_beats.get_text()
-                self.activity_data[self.active_row]["rcd_calories"] = self.rcd_calories.get_text()
+                self.activity_data[self.active_row]["rcd_maxpace"] = gtk_str(self.rcd_maxpace.get_text())
+                self.activity_data[self.active_row]["rcd_pace"] = gtk_str(self.rcd_pace.get_text())
+                self.activity_data[self.active_row]["rcd_upositive"] = gtk_str(self.rcd_upositive.get_text())
+                self.activity_data[self.active_row]["rcd_unegative"] = gtk_str(self.rcd_unegative.get_text())
+                self.activity_data[self.active_row]["rcd_maxbeats"] = gtk_str(self.rcd_maxbeats.get_text())
+                self.activity_data[self.active_row]["rcd_beats"] = gtk_str(self.rcd_beats.get_text())
+                self.activity_data[self.active_row]["rcd_calories"] = gtk_str(self.rcd_calories.get_text())
             row = 0 
             for activity in self.activity_data:
                 index = self.activity_data.index(activity)
                 if activity["complete"] is False:
                     #Did not view or modify this record - need to get all the details
-                    print "Activity incomplete.. " + activity["rcd_gpxfile"]
+                    logging.debug("Activity incomplete.. %s", activity["rcd_gpxfile"])
                     self.update_activity_data(row, activity["rcd_gpxfile"], activity["rcd_sport"])
                 activity["rcd_title"] = activity["rcd_title"].replace("\"","'")
                 #Add activity to DB etc
@@ -245,37 +251,41 @@ class WindowRecord(SimpleBuilderApp):
                 selected_equipment_ids = self._get_selected_equipment_ids()
                 self.activity_data[index]["db_id"] = self.parent.insertRecord(activity, laps, equipment=selected_equipment_ids)
                 row += 1
-            logging.debug("Processed %d rows of activity data" % row)
+            logging.debug("Processed %d rows of activity data", row)
         else:
             logging.debug("Single activity")
             list_options = {}
             trackSummary = {}
-            list_options["rcd_date"] = self.rcd_date.get_text()
-            list_options["rcd_sport"] = self.rcd_sport.get_active_text()
-            list_options["rcd_distance"] = self.uc.usr2sys_str('distance', self.rcd_distance.get_text())
-            list_options["rcd_beats"] = self.rcd_beats.get_text()
-            list_options["rcd_average"] = self.uc.usr2sys_str('speed', self.rcd_average.get_text())
-            list_options["rcd_calories"] = self.rcd_calories.get_text()
-            list_options["rcd_title"] = self.rcd_title.get_text().replace("\"","'")
-            list_options["rcd_gpxfile"] = self.rcd_gpxfile.get_text()
-            list_options["rcd_upositive"] = self.uc.usr2sys_str('height', self.rcd_upositive.get_text())
-            list_options["rcd_unegative"] = self.uc.usr2sys_str('height', self.rcd_unegative.get_text())
-            list_options["rcd_maxbeats"] = self.rcd_maxbeats.get_text()
+            list_options["rcd_date"] = gtk_str(self.rcd_date.get_text())
+            list_options["rcd_sport"] = gtk_str(self.rcd_sport.get_active_text())
+            list_options["rcd_distance"] = self.uc.usr2sys_str('distance',
+                                                               gtk_str(self.rcd_distance.get_text()))
+            list_options["rcd_beats"] = gtk_str(self.rcd_beats.get_text())
+            list_options["rcd_average"] = self.uc.usr2sys_str('speed',
+                                                              gtk_str(self.rcd_average.get_text()))
+            list_options["rcd_calories"] = gtk_str(self.rcd_calories.get_text())
+            list_options["rcd_title"] = gtk_str(self.rcd_title.get_text())
+            list_options["rcd_gpxfile"] = gtk_str(self.rcd_gpxfile.get_text())
+            list_options["rcd_upositive"] = self.uc.usr2sys_str('height',
+                                                                gtk_str(self.rcd_upositive.get_text()))
+            list_options["rcd_unegative"] = self.uc.usr2sys_str('height',
+                                                                gtk_str(self.rcd_unegative.get_text()))
+            list_options["rcd_maxbeats"] = gtk_str(self.rcd_maxbeats.get_text())
             # 2011.11.05 - dgranda
             # Pace is shown to user in mm:ss format
             # But pace in database is stored in a mixed way: 4.30 for 4:30 (4.5 in 'decimal'). This needs to be changed!!
-            list_options["rcd_pace"] = self.uc.usr2sys_str('pace', self.rcd_pace.get_text().replace(":","."))
-            list_options["rcd_maxpace"] = self.uc.usr2sys_str('pace', self.rcd_maxpace.get_text().replace(":","."))
-            list_options["rcd_maxvel"] = self.uc.usr2sys_str('speed', self.rcd_maxvel.get_text())
+            list_options["rcd_pace"] = self.uc.usr2sys_str('pace', gtk_str(self.rcd_pace.get_text()).replace(":","."))
+            list_options["rcd_maxpace"] = self.uc.usr2sys_str('pace', gtk_str(self.rcd_maxpace.get_text()).replace(":","."))
+            list_options["rcd_maxvel"] = self.uc.usr2sys_str('speed', gtk_str(self.rcd_maxvel.get_text()))
             list_options["rcd_time"] = [self.rcd_hour.get_value_as_int(),self.rcd_min.get_value_as_int(),self.rcd_second.get_value_as_int()]
             buffer = self.rcd_comments.get_buffer()
             start,end = buffer.get_bounds()
-            comment = buffer.get_text(start,end, True)
-            list_options["rcd_comments"] = comment.replace("\"","'")
+            comment = gtk_str(buffer.get_text(start,end, True))
+            list_options["rcd_comments"] = comment
             selected_equipment_ids = self._get_selected_equipment_ids()
             # Added to change start time, only activities without GPX+ source file - dgranda 2011/06/10
-            record_time = self.rcd_starttime.get_text()
-            record_date = self.rcd_date.get_text()
+            record_time = gtk_str(self.rcd_starttime.get_text())
+            record_date = gtk_str(self.rcd_date.get_text())
             localtz = getLocalTZ()
             date = dateutil.parser.parse(record_date+" "+record_time+" "+localtz)
             local_date = str(date)
@@ -284,22 +294,33 @@ class WindowRecord(SimpleBuilderApp):
             list_options["date_time_local"] = local_date
 
             if self.mode == "newrecord":
-                logging.debug('Track data: '+str(list_options))
+                logging.debug('Track data: %s', list_options)
                 if list_options["rcd_gpxfile"] != "":
                     logging.info('Adding new activity based on GPX file')
                     self.parent.insertRecord(list_options, None, selected_equipment_ids)
                 else:
                     logging.info('Adding new activity based on provided data')
                     #Manual entry, calculate time info
-                    record_time = self.rcd_starttime.get_text()
-                    record_date = self.rcd_date.get_text()
+                    record_time = gtk_str(self.rcd_starttime.get_text())
+                    record_date = gtk_str(self.rcd_date.get_text())
                     localtz = getLocalTZ()
                     date = dateutil.parser.parse(record_date+" "+record_time+" "+localtz)
                     local_date = str(date)
                     utc_date = date.astimezone(tzutc()).strftime("%Y-%m-%dT%H:%M:%SZ")
                     list_options["date_time_utc"] = utc_date
                     list_options["date_time_local"] = local_date
-                    self.parent.insertRecord(list_options, equipment=selected_equipment_ids)
+
+                    try:
+                        self.parent.insertRecord(
+                                list_options,
+                                equipment=selected_equipment_ids)
+                    except ValueError:
+                        msg = ("Unable to add an activity record without any "
+                               "sports, please add a sport in preferences' "
+                               "<i>Sports</i> tab.")
+                        logging.error(msg)
+                        warning_dialog(title=_("Error Adding Activity Record"), text=_(msg))
+
             elif self.mode == "editrecord":
                 self.parent.updateRecord(list_options, self.id_record, equipment=selected_equipment_ids)
         logging.debug("<<")
@@ -314,7 +335,7 @@ class WindowRecord(SimpleBuilderApp):
         self.quit()
 
     def on_calendar_clicked(self,widget):
-        calendardialog = WindowCalendar(self.data_path,self, date=self.rcd_date.get_text())
+        calendardialog = WindowCalendar(self.data_path,self, date=gtk_str(self.rcd_date.get_text()))
         calendardialog.run()
 
     def setDate(self,date):
@@ -335,7 +356,7 @@ class WindowRecord(SimpleBuilderApp):
             valueString = format % value
             var.set_text(valueString)
         except Exception as e:
-            print var_name, value, e
+            logging.debug("setValue: %s, %s, %s", var_name, value, e)
             pass
     
     def setValuesFromActivity(self, activity):
@@ -388,7 +409,7 @@ class WindowRecord(SimpleBuilderApp):
     def setValues(self,values):
         #(24, u'2009-12-26', 4, 23.48, u'9979', 0.0, 8.4716666232200009, 2210, u'', None, u'', 573.0, 562.0, 11.802745244400001, 5.0499999999999998, 7.04, 0.0, u'2009-12-25T19:41:48Z', u'2009-12-26 08:41:48+13:00')
         #(50, u'2006-10-13', 1, 25.0, u'5625', 0.0, 16.0, 0, u'', gpsfile, title,upositive,unegative,maxspeed|maxpace|pace|maxbeats
-        print "windowrecord setValues called"
+        logging.debug("windowrecord setValues called")
         self.mode = "editrecord"
         self.id_record = values[0]
         self.setTime(values[4])
@@ -423,7 +444,7 @@ class WindowRecord(SimpleBuilderApp):
             Needed as once sports are deleted there are gaps in the list...
         """
         count = 0
-        for key, value in self.listSport.iteritems():
+        for key, value in self.listSport.items():
             if key == sportID: 
                 return count
             count +=1
@@ -435,7 +456,7 @@ class WindowRecord(SimpleBuilderApp):
             Needed as once sports are deleted there are gaps in the list...
         """
         count = 0
-        for key, value in self.listSport.iteritems():
+        for key, value in self.listSport.items():
             if value == sport: 
                 return count
             count +=1
@@ -444,21 +465,23 @@ class WindowRecord(SimpleBuilderApp):
     def on_calctime_clicked(self,widget):
         logging.debug(">>")
         try:
-            distance = float(self.rcd_distance.get_text()) # distance is mandatory!
+            distance = float(gtk_str(self.rcd_distance.get_text())) # distance is mandatory!
             # we need either pace or speed
             try:
-                average = float(self.rcd_average.get_text())
+                average = float(gtk_str(self.rcd_average.get_text()))
                 time_in_hour = distance/average
-                logging.debug("Distance: %0.3f km (mi) | Speed: %0.2f -> Time: %.f hours  " %(distance,average,time_in_hour)) 
+                logging.debug("Distance: %0.3f km (mi) | Speed: %0.2f -> Time: %.f hours",
+                              distance, average, time_in_hour)
                 pace = self.parent.pace_from_float(60/average)
-                logging.debug("Setting pace: %s" %pace)
+                logging.debug("Setting pace: %s", pace)
                 self.rcd_pace.set_text(pace)
             except:
-                pace_dec = self.parent.pace_to_float(self.rcd_pace.get_text())
+                pace_dec = self.parent.pace_to_float(gtk_str(self.rcd_pace.get_text()))
                 time_in_hour = pace_dec*distance/60.0
-                logging.debug("Distance: %0.3f km (mi) | Pace_dec: %0.2f -> Time: %.f hours" %(distance,pace_dec,time_in_hour))
+                logging.debug("Distance: %0.3f km (mi) | Pace_dec: %0.2f -> Time: %.f hours",
+                              distance, pace_dec, time_in_hour)
                 speed = distance/time_in_hour
-                logging.debug("Setting average speed: %0.2f" %speed)
+                logging.debug("Setting average speed: %0.2f", speed)
                 self.rcd_average.set_text("%0.2f" %speed)
             self.set_recordtime(time_in_hour)
         except:
@@ -521,8 +544,8 @@ class WindowRecord(SimpleBuilderApp):
         if "rcd_comments" not in self.activity_data[row]:
             self.activity_data[row]["rcd_comments"] = ""
         buffer.set_text(self.activity_data[row]["rcd_comments"])
-        while gtk.events_pending(): # This allows the GUI to update 
-            gtk.main_iteration()    # before completion of this entire action
+        while Gtk.events_pending(): # This allows the GUI to update
+            Gtk.main_iteration()    # before completion of this entire action
         if self.activity_data[row]["complete"] is False:
             #Haven't processed GPX file yet
             #Blank values not yet known
@@ -537,8 +560,8 @@ class WindowRecord(SimpleBuilderApp):
             self.rcd_maxpace.set_text("")
             self.rcd_pace.set_text("")
             self.setValue("rcd_maxbeats", "", "%s")
-            while gtk.events_pending(): # This allows the GUI to update 
-                gtk.main_iteration()    # before completion of this entire action
+            while Gtk.events_pending(): # This allows the GUI to update
+                Gtk.main_iteration()    # before completion of this entire action
             #Get some info from gpx file
             self.update_activity_data(row, gpx_file, sport)
         self.setValue("rcd_distance",self.activity_data[row]["rcd_distance"], "%s") 
@@ -561,11 +584,11 @@ class WindowRecord(SimpleBuilderApp):
         
     def on_rcd_title_changed(self, widget):
         if self.mode == "multiple_activities" and self.active_row is not None:
-            self.activity_data[self.active_row]["rcd_title"] = self.rcd_title.get_text()
+            self.activity_data[self.active_row]["rcd_title"] = gtk_str(self.rcd_title.get_text())
             
     def on_rcd_sport_changed(self, widget):
         if self.mode == "multiple_activities" and self.active_row is not None:
-            sport = self.rcd_sport.get_active_text()
+            sport = gtk_str(self.rcd_sport.get_active_text())
             #Update sport in data store
             self.activity_data[self.active_row]["rcd_sport"] = sport
             #Update sport in treeview
@@ -573,7 +596,7 @@ class WindowRecord(SimpleBuilderApp):
             
     def on_rcd_distance_changed(self, widget):
         if self.mode == "multiple_activities" and self.active_row is not None:
-            distance = self.rcd_distance.get_text()
+            distance = gtk_str(self.rcd_distance.get_text())
             #Update distance in data store
             self.activity_data[self.active_row]["rcd_distance"] = distance
             #Update distance in treeview
@@ -593,12 +616,12 @@ class WindowRecord(SimpleBuilderApp):
     def on_rcd_date_changed(self, widget):
         if self.mode == "multiple_activities" and self.active_row is not None:
             #Update date in data store
-            self.activity_data[self.active_row]["rcd_date"] = self.rcd_date.get_text()
+            self.activity_data[self.active_row]["rcd_date"] = gtk_str(self.rcd_date.get_text())
             
     def on_rcd_starttime_changed(self, widget):
         if self.mode == "multiple_activities" and self.active_row is not None:
             #Update start time in data store
-            self.activity_data[self.active_row]["rcd_starttime"] = self.rcd_starttime.get_text()
+            self.activity_data[self.active_row]["rcd_starttime"] = gtk_str(self.rcd_starttime.get_text())
             
     def on_treeviewEntries_row_activated(self, treeview, event):
         '''
@@ -609,16 +632,16 @@ class WindowRecord(SimpleBuilderApp):
             #Check for edited data in comments
             buffer = self.rcd_comments.get_buffer()
             start,end = buffer.get_bounds()
-            comments = buffer.get_text(start,end, True).replace("\"","'")
+            comments = gtk_str(buffer.get_text(start,end, True))
             self.activity_data[self.active_row]["rcd_comments"] = comments
             #Advanced tab items
-            self.activity_data[self.active_row]["rcd_maxpace"] = self.rcd_maxpace.get_text()
-            self.activity_data[self.active_row]["rcd_pace"] = self.rcd_pace.get_text()
-            self.activity_data[self.active_row]["rcd_upositive"] = self.rcd_upositive.get_text()
-            self.activity_data[self.active_row]["rcd_unegative"] = self.rcd_unegative.get_text()
-            self.activity_data[self.active_row]["rcd_maxbeats"] = self.rcd_maxbeats.get_text()
-            self.activity_data[self.active_row]["rcd_beats"] = self.rcd_beats.get_text()
-            self.activity_data[self.active_row]["rcd_calories"] = self.rcd_calories.get_text()
+            self.activity_data[self.active_row]["rcd_maxpace"] = gtk_str(self.rcd_maxpace.get_text())
+            self.activity_data[self.active_row]["rcd_pace"] = gtk_str(self.rcd_pace.get_text())
+            self.activity_data[self.active_row]["rcd_upositive"] = gtk_str(self.rcd_upositive.get_text())
+            self.activity_data[self.active_row]["rcd_unegative"] = gtk_str(self.rcd_unegative.get_text())
+            self.activity_data[self.active_row]["rcd_maxbeats"] = gtk_str(self.rcd_maxbeats.get_text())
+            self.activity_data[self.active_row]["rcd_beats"] = gtk_str(self.rcd_beats.get_text())
+            self.activity_data[self.active_row]["rcd_calories"] = gtk_str(self.rcd_calories.get_text())
         #Get row that was selected
         x = int(event.x)
         y = int(event.y)
@@ -628,8 +651,8 @@ class WindowRecord(SimpleBuilderApp):
             path, col, cellx, celly = pthinfo
             treeview.grab_focus()
             treeview.set_cursor(path, col, 0)
-            while gtk.events_pending(): # This allows the GUI to update 
-                gtk.main_iteration()    # before completion of this entire action
+            while Gtk.events_pending(): # This allows the GUI to update
+                Gtk.main_iteration()    # before completion of this entire action
             self.show_treeviewEntries_row(path[0])
 
     def on_calcavs_clicked(self,widget):
@@ -639,27 +662,27 @@ class WindowRecord(SimpleBuilderApp):
         sec = self.rcd_second.get_value_as_int()
         time = sec + (min*60) + (hour*3600)
         if time<1:
-            logging.debug("Seems no time value (%s) has been entered, nothing to calculate." %time)
+            logging.debug("Seems no time value (%s) has been entered, nothing to calculate.", time)
             return False
-        distance = float(self.rcd_distance.get_text())
+        distance = float(gtk_str(self.rcd_distance.get_text()))
         if distance<1:
-            logging.debug("Seems no distance value (%s) has been entered, nothing to calculate." %distance)
+            logging.debug("Seems no distance value (%s) has been entered, nothing to calculate.", distance)
             return False
-        logging.debug("Time: %d seconds | Distance: %0.2f km (mi)" %(time,distance))
+        logging.debug("Time: %d seconds | Distance: %0.2f km (mi)", time, distance)
         # Average speed        
         average_speed = distance*3600.0/time
-        logging.debug("Average speed: %0.2f" %average_speed)
+        logging.debug("Average speed: %0.2f", average_speed)
         self.rcd_average.set_text("%0.2f" %average_speed)
         # Average pace 
         dec_pace = 60/average_speed
         #Transform pace to mm:ss
         pace = self.parent.pace_from_float(dec_pace)
-        logging.debug("Average pace: %s" %pace)
+        logging.debug("Average pace: %s", pace)
         self.rcd_pace.set_text(pace)
         logging.debug("<<")
 
     def on_calccalories_clicked(self,widget):
-        sport = self.rcd_sport.get_active_text()
+        sport = gtk_str(self.rcd_sport.get_active_text())
         hour = self.rcd_hour.get_value_as_int()
         min = self.rcd_min.get_value_as_int()
         sec = self.rcd_second.get_value_as_int()
@@ -692,18 +715,20 @@ class WindowRecord(SimpleBuilderApp):
             time_in_hour = time/3600.0
             # we need either pace or speed
             try:
-                average = float(self.rcd_average.get_text())
+                average = float(gtk_str(self.rcd_average.get_text()))
                 distance = average*time_in_hour
-                logging.debug("Time: %d seconds | Speed: %0.2f -> Distance: %0.3f km (mi)" %(time,average,distance)) 
+                logging.debug("Time: %d seconds | Speed: %0.2f -> Distance: %0.3f km (mi)",
+                              time, average, distance)
                 pace = self.parent.pace_from_float(60/average)
-                logging.debug("Setting pace: %s" %pace)
+                logging.debug("Setting pace: %s", pace)
                 self.rcd_pace.set_text(pace)
             except:
-                pace_dec = self.parent.pace_to_float(self.rcd_pace.get_text())
+                pace_dec = self.parent.pace_to_float(gtk_str(self.rcd_pace.get_text()))
                 distance = time/(60.0*pace_dec)
-                logging.debug("Time: %d seconds | Pace_dec: %0.2f -> Distance: %0.3f km (mi)" %(time,pace_dec,distance))
+                logging.debug("Time: %d seconds | Pace_dec: %0.2f -> Distance: %0.3f km (mi)",
+                              time, pace_dec, distance)
                 speed = distance/time_in_hour
-                logging.debug("Setting average speed: %0.2f" %speed)
+                logging.debug("Setting average speed: %0.2f", speed)
                 self.rcd_average.set_text("%0.2f" %speed)
             self.set_distance(distance) 
         except:
@@ -742,7 +767,7 @@ class WindowRecord(SimpleBuilderApp):
         logging.debug("<<")
 
     def on_calculatevalues_clicked(self,widget):
-        gpxfile = self.rcd_gpxfile.get_text()
+        gpxfile = gtk_str(self.rcd_gpxfile.get_text())
         if os.path.isfile(gpxfile):
             self.frameGeneral.set_sensitive(0)
             self.frameVelocity.set_sensitive(0) 
