@@ -23,26 +23,30 @@ from optparse import OptionParser
 import logging
 import logging.handlers
 import traceback
+import warnings
 
-from pytrainer.util.date import DateRange
-from upgrade.data import initialize_data
-from environment import Environment
-from record import Record
-from waypoint import Waypoint
-from extension import Extension
-from importdata import Importdata
-from plugins import Plugins
-from profile import Profile
+import gi
+gi.require_version('Gtk', '3.0')
+
+from pytrainer.lib.date import DateRange
+from .upgrade.data import initialize_data
+from .environment import Environment
+from .record import Record
+from .waypoint import WaypointService
+from .extension import Extension
+from .importdata import Importdata
+from .plugins import Plugins
+from .profile import Profile
 from pytrainer.core.sport import SportService
-from athlete import Athlete
-from stats import Stats
+from .athlete import Athlete
+from .stats import Stats
 
-from gui.windowmain import Main
-from gui.warning import Warning
-from lib.date import Date, getNameMonth
+from .gui.windowmain import Main
+from .gui.warning import Warning
+from .lib.date import Date, getNameMonth
 from pytrainer.core.activity import ActivityService
-from lib.ddbb import DDBB
-from lib.uc import UC
+from .lib.ddbb import DDBB
+from .lib.uc import UC
 
 class pyTrainer:
     def __init__(self,filename = None, data_path = None):
@@ -66,7 +70,7 @@ class pyTrainer:
         self.profile.saveProfile()
         self.uc = UC()
         self.profilewindow = None
-        self.ddbb = DDBB(self.profile)
+        self.ddbb = DDBB(self.profile.sqlalchemy_url)
         logging.debug('connecting to DDBB')
         self.ddbb.connect()
 
@@ -81,7 +85,7 @@ class pyTrainer:
         logging.debug('Loading athlete service...')
         self.athlete = Athlete(data_path, self)
         logging.debug('Loading stats service...')
-        self.stats = Stats(self._sport_service, self)
+        self.stats = Stats(self)
         logging.debug('Initializing activity pool...')
         pool_size = self.profile.getIntValue("pytraining","activitypool_size", default=1)
         self.activitypool = ActivityService(self, size=pool_size)
@@ -95,7 +99,7 @@ class pyTrainer:
         self.selectInitialDate()
         
         logging.debug('Loading waypoint service...')
-        self.waypoint = Waypoint(data_path,self)
+        self.waypoint = WaypointService(data_path, self)
         logging.debug('Loading extension service...')
         self.extension = Extension(data_path, self)
         logging.debug('Loading plugins service...')
@@ -141,6 +145,7 @@ class pyTrainer:
 
     def set_logging(self, level, log_type):
         '''Setup rotating log file with customized format'''
+        logging.captureWarnings(True)
         if("console" == log_type):
             handler = logging.StreamHandler(sys.stdout)
         else:
@@ -152,8 +157,9 @@ class pyTrainer:
 
     def set_logging_level(self, level):
         '''Set level of information written to log'''
-        logging.debug("Setting logger to level: "+ str(level))
+        logging.debug("Setting logger to level: %s", level)
         logging.getLogger('').setLevel(level)
+        logging.getLogger('sqlalchemy.engine').setLevel(level)
 
     def quit(self):
         logging.debug('--')
@@ -192,8 +198,8 @@ class pyTrainer:
                 # Only showing garmintools_full and garmin-hr in 'File' dropdown
                 plugin_name = os.path.basename(plugin)
                 if (plugin_name == "garmintools_full" or plugin_name == "garmin-hr"):
-                    txtbutton = self.plugins.loadPlugin(plugin)
-                    self.windowmain.addImportPlugin(txtbutton)
+                    warnings.warn('Attempted to enable an unsupported plugin %s' % plugin_name,
+                                  UserWarning)
                 else:
                     logging.debug('From version 1.10 on, file import plugins are managed via File -> Import. Not displaying plugin ' + plugin_name)
         logging.debug('<<')
@@ -269,35 +275,20 @@ class pyTrainer:
                 self.refreshRecordGraphView("analytics")
         elif view=="day":
              logging.debug('day view')
-             sport = self.windowmain.activeSport
-             sport_id = self.record.getSportId(sport)
-             record_list = self.record.getrecordList(date_selected, sport_id)
-             self.windowmain.actualize_dayview(record_list=record_list)
-             #selected,iter = self.windowmain.recordTreeView.get_selection().get_selected()
+             self.windowmain.actualize_dayview(date_selected)
         elif view=="week":
              logging.debug('week view')
              date_range = DateRange.for_week_containing(date_selected)
-             sport = self.windowmain.activeSport
-             sport_id = self.record.getSportId(sport)
-             record_list = self.record.getrecordPeriod(date_range, sport_id)
-             self.windowmain.actualize_weekview(record_list, date_range)
+             self.windowmain.actualize_weekview(date_range)
         elif view=="month":
              logging.debug('month view')
              date_range = DateRange.for_month_containing(date_selected)
-             sport = self.windowmain.activeSport
-             sport_id = self.record.getSportId(sport)
-             record_list = self.record.getrecordPeriod(date_range, sport_id)
              nameMonth, daysInMonth = getNameMonth(date_selected)
-             self.windowmain.actualize_monthview(record_list, nameMonth)
-             self.windowmain.actualize_monthgraph(record_list, daysInMonth)
+             self.windowmain.actualize_monthview(date_range, nameMonth, daysInMonth)
         elif view=="year":
              logging.debug('year view')
              date_range = DateRange.for_year_containing(date_selected)
-             sport = self.windowmain.activeSport
-             sport_id = self.record.getSportId(sport)
-             record_list = self.record.getrecordPeriod(date_range, sport_id)
-             self.windowmain.actualize_yearview(record_list, date_selected.year)
-             self.windowmain.actualize_yeargraph(record_list)
+             self.windowmain.actualize_yearview(date_range, date_selected.year)
         elif view=="listview":
             logging.debug('list view')
             self.refreshListView()
@@ -308,20 +299,20 @@ class pyTrainer:
             logging.debug('stats view')
             self.windowmain.on_statsview_activate()
         else:
-            print "Unknown view %s" % view
+            logging.error("Unknown view %s", view)
         logging.debug('<<')
         
     def refreshRecordGraphView(self, view, id_record=None):
         logging.debug('>>')
         logging.info('Working on '+view+' graph')
         if id_record is not None:
-			#Refresh called for a specific record
+            #Refresh called for a specific record
             #Select correct record in treeview
             model = self.windowmain.recordTreeView.get_model()
             #Loop through all records in treeview looking for the correct one to highlight
             for i,row in enumerate(model):
-				if row[0] == id_record:
-					self.windowmain.recordTreeView.set_cursor(i)
+                if row[0] == id_record:
+                    self.windowmain.recordTreeView.set_cursor(i)
         else:
             selected,iter = self.windowmain.recordTreeView.get_selection().get_selected()
             if iter:
@@ -352,7 +343,7 @@ class pyTrainer:
         selected,iter = self.windowmain.recordTreeView.get_selection().get_selected()
         id_record = selected.get_value(iter,0)
         activity = self.activitypool.get_activity(id_record)
-        logging.debug('Trying to show map for record '+str(id_record))
+        logging.debug('Trying to show map for record %s', id_record)
         self.windowmain.actualize_map(activity, full_screen)
         logging.debug('<<')
 
@@ -360,12 +351,13 @@ class pyTrainer:
         logging.debug('>>')
         #Refresh list records
         date = self.date.getDate()
-        sport = self.windowmain.activeSport
-        id_sport = self.record.getSportId(sport)
-        record_ids = self.record.getrecordList(date, id_sport)
-        self.windowmain.actualize_recordTreeView(record_ids)
+        if self.windowmain.activeSport:
+            sport = self._sport_service.get_sport_by_name(self.windowmain.activeSport)
+        else:
+            sport = None
+        self.windowmain.actualize_recordTreeView(date)
         #Mark the monthly calendar to show which days have activity?
-        record_list = self.record.getRecordDayList(date, id_sport)
+        record_list = self.record.getRecordDayList(date, sport)
         self.windowmain.actualize_calendar(record_list)
         logging.debug('<<')
 
@@ -378,7 +370,7 @@ class pyTrainer:
     def refreshStatsView(self):
         logging.debug('>>')
         self.stats.refresh()
-        self.windowmain.actualize_statsview(self.stats, self.record.getAllRecordList())
+        self.windowmain.actualize_statsview(self.stats, self.activitypool.get_all_activities())
         logging.debug('<<')
 
     def refreshListView(self,condition=None):
@@ -435,8 +427,8 @@ class pyTrainer:
                 #new active plugin -> need to load plugin
                 plugin_name = os.path.basename(plugin)
                 if (plugin_name == "garmintools_full" or plugin_name == "garmin-hr"):
-                    txtbutton = self.plugins.loadPlugin(plugin)
-                    self.windowmain.addImportPlugin(txtbutton)
+                    warnings.warn('Attempted to enable an unsupported plugin %s' % plugin_name,
+                                  UserWarning)
                 else:
                     logging.debug('From version 1.10 on file import plugins are managed via File -> Import. Not displaying plugin ' + plugin_name)
         logging.debug('<<')
@@ -447,7 +439,7 @@ class pyTrainer:
         for extension in before:
             if extension not in after:
                 #disabled extension -> need to unload extension
-                print "Need to disable extension %s " % extension
+                logging.error("Need to disable extension %s", extension)
                 txtbutton = self.extension.loadExtension(extension)
                 self.windowmain.removeExtension(txtbutton)
         #Need to check for plugins that have been enabled (were not active and now are)
@@ -479,7 +471,8 @@ class pyTrainer:
     def removeRecord(self, id_record, confirm = False, view=None):
         logging.debug('>>')
         if confirm:
-             self.record.removeRecord(id_record)
+             activity = self.activitypool.get_activity(id_record)
+             self.activitypool.remove_activity_from_db(activity)
         else:
              msg = _("Delete this database entry?")
              params = [id_record,True]
@@ -512,14 +505,14 @@ class pyTrainer:
 
     def exportCsv(self):
         logging.debug('>>')
-        from save import Save
+        from .save import Save
         save = Save(self.data_path, self.record)
         save.run()
         logging.debug('<<')
 
     def editProfile(self):
         logging.debug('>>')
-        from gui.windowprofile import WindowProfile
+        from .gui.windowprofile import WindowProfile
         self.profile.refreshConfiguration()
         if self.profilewindow is None:
             self.profilewindow = WindowProfile(self._sport_service, self.data_path, self.profile, pytrainer_main=self)
