@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
-from lib.fileUtils import fileUtils
+from .lib.fileUtils import fileUtils
 from pytrainer.gui.dialogs import save_file_chooser_dialog
 import logging
 import traceback
